import enum

class AccessInvitationErrorEnum:
    class AccessInvitationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_EMAIL_ADDRESS: int = ...
        EMAIL_ADDRESS_ALREADY_HAS_ACCESS: int = ...

class AccessReasonEnum:
    class AccessReason(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        OWNED: int = ...
        SHARED: int = ...
        LICENSED: int = ...
        SUBSCRIBED: int = ...
        AFFILIATED: int = ...

class AccessRoleEnum:
    class AccessRole(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ADMIN: int = ...
        STANDARD: int = ...
        READ_ONLY: int = ...

class AccountBudgetProposalErrorEnum:
    class AccountBudgetProposalError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FIELD_MASK_NOT_ALLOWED: int = ...
        IMMUTABLE_FIELD: int = ...
        REQUIRED_FIELD_MISSING: int = ...
        CANNOT_CANCEL_APPROVED_PROPOSAL: int = ...
        CANNOT_REMOVE_UNAPPROVED_BUDGET: int = ...
        CANNOT_REMOVE_RUNNING_BUDGET: int = ...
        CANNOT_END_UNAPPROVED_BUDGET: int = ...
        CANNOT_END_INACTIVE_BUDGET: int = ...
        BUDGET_NAME_REQUIRED: int = ...
        CANNOT_UPDATE_OLD_BUDGET: int = ...
        CANNOT_END_IN_PAST: int = ...
        CANNOT_EXTEND_END_TIME: int = ...
        PURCHASE_ORDER_NUMBER_REQUIRED: int = ...
        PENDING_UPDATE_PROPOSAL_EXISTS: int = ...
        MULTIPLE_BUDGETS_NOT_ALLOWED_FOR_UNAPPROVED_BILLING_SETUP: int = ...
        CANNOT_UPDATE_START_TIME_FOR_STARTED_BUDGET: int = ...
        SPENDING_LIMIT_LOWER_THAN_ACCRUED_COST_NOT_ALLOWED: int = ...
        UPDATE_IS_NO_OP: int = ...
        END_TIME_MUST_FOLLOW_START_TIME: int = ...
        BUDGET_DATE_RANGE_INCOMPATIBLE_WITH_BILLING_SETUP: int = ...
        NOT_AUTHORIZED: int = ...
        INVALID_BILLING_SETUP: int = ...

class AccountBudgetProposalStatusEnum:
    class AccountBudgetProposalStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PENDING: int = ...
        APPROVED_HELD: int = ...
        APPROVED: int = ...
        CANCELLED: int = ...
        REJECTED: int = ...

class AccountBudgetProposalTypeEnum:
    class AccountBudgetProposalType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CREATE: int = ...
        UPDATE: int = ...
        END: int = ...
        REMOVE: int = ...

class AccountBudgetStatusEnum:
    class AccountBudgetStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PENDING: int = ...
        APPROVED: int = ...
        CANCELLED: int = ...

class AdCustomizerErrorEnum:
    class AdCustomizerError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        COUNTDOWN_INVALID_DATE_FORMAT: int = ...
        COUNTDOWN_DATE_IN_PAST: int = ...
        COUNTDOWN_INVALID_LOCALE: int = ...
        COUNTDOWN_INVALID_START_DAYS_BEFORE: int = ...
        UNKNOWN_USER_LIST: int = ...

class AdCustomizerPlaceholderFieldEnum:
    class AdCustomizerPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INTEGER: int = ...
        PRICE: int = ...
        DATE: int = ...
        STRING: int = ...

class AdErrorEnum:
    class AdError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE: int = ...
        APPROXIMATELY_TOO_LONG: int = ...
        APPROXIMATELY_TOO_SHORT: int = ...
        BAD_SNIPPET: int = ...
        CANNOT_MODIFY_AD: int = ...
        CANNOT_SET_BUSINESS_NAME_IF_URL_SET: int = ...
        CANNOT_SET_FIELD: int = ...
        CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET: int = ...
        CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING: int = ...
        CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE: int = ...
        CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING: int = ...
        CANNOT_SET_URL: int = ...
        CANNOT_SET_WITHOUT_FINAL_URLS: int = ...
        CANNOT_SET_WITH_FINAL_URLS: int = ...
        CANNOT_SET_WITH_URL_DATA: int = ...
        CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR: int = ...
        CUSTOMER_NOT_APPROVED_MOBILEADS: int = ...
        CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS: int = ...
        CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS: int = ...
        CUSTOMER_NOT_ELIGIBLE: int = ...
        CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL: int = ...
        DIMENSION_ALREADY_IN_UNION: int = ...
        DIMENSION_MUST_BE_SET: int = ...
        DIMENSION_NOT_IN_UNION: int = ...
        DISPLAY_URL_CANNOT_BE_SPECIFIED: int = ...
        DOMESTIC_PHONE_NUMBER_FORMAT: int = ...
        EMERGENCY_PHONE_NUMBER: int = ...
        EMPTY_FIELD: int = ...
        FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID: int = ...
        FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH: int = ...
        ILLEGAL_AD_CUSTOMIZER_TAG_USE: int = ...
        ILLEGAL_TAG_USE: int = ...
        INCONSISTENT_DIMENSIONS: int = ...
        INCONSISTENT_STATUS_IN_TEMPLATE_UNION: int = ...
        INCORRECT_LENGTH: int = ...
        INELIGIBLE_FOR_UPGRADE: int = ...
        INVALID_AD_ADDRESS_CAMPAIGN_TARGET: int = ...
        INVALID_AD_TYPE: int = ...
        INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE: int = ...
        INVALID_ATTRIBUTES_FOR_MOBILE_TEXT: int = ...
        INVALID_CALL_TO_ACTION_TEXT: int = ...
        INVALID_CHARACTER_FOR_URL: int = ...
        INVALID_COUNTRY_CODE: int = ...
        INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG: int = ...
        INVALID_INPUT: int = ...
        INVALID_MARKUP_LANGUAGE: int = ...
        INVALID_MOBILE_CARRIER: int = ...
        INVALID_MOBILE_CARRIER_TARGET: int = ...
        INVALID_NUMBER_OF_ELEMENTS: int = ...
        INVALID_PHONE_NUMBER_FORMAT: int = ...
        INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID: int = ...
        INVALID_TEMPLATE_DATA: int = ...
        INVALID_TEMPLATE_ELEMENT_FIELD_TYPE: int = ...
        INVALID_TEMPLATE_ID: int = ...
        LINE_TOO_WIDE: int = ...
        MISSING_AD_CUSTOMIZER_MAPPING: int = ...
        MISSING_ADDRESS_COMPONENT: int = ...
        MISSING_ADVERTISEMENT_NAME: int = ...
        MISSING_BUSINESS_NAME: int = ...
        MISSING_DESCRIPTION1: int = ...
        MISSING_DESCRIPTION2: int = ...
        MISSING_DESTINATION_URL_TAG: int = ...
        MISSING_LANDING_PAGE_URL_TAG: int = ...
        MISSING_DIMENSION: int = ...
        MISSING_DISPLAY_URL: int = ...
        MISSING_HEADLINE: int = ...
        MISSING_HEIGHT: int = ...
        MISSING_IMAGE: int = ...
        MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS: int = ...
        MISSING_MARKUP_LANGUAGES: int = ...
        MISSING_MOBILE_CARRIER: int = ...
        MISSING_PHONE: int = ...
        MISSING_REQUIRED_TEMPLATE_FIELDS: int = ...
        MISSING_TEMPLATE_FIELD_VALUE: int = ...
        MISSING_TEXT: int = ...
        MISSING_VISIBLE_URL: int = ...
        MISSING_WIDTH: int = ...
        MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED: int = ...
        MUST_USE_TEMP_AD_UNION_ID_ON_ADD: int = ...
        TOO_LONG: int = ...
        TOO_SHORT: int = ...
        UNION_DIMENSIONS_CANNOT_CHANGE: int = ...
        UNKNOWN_ADDRESS_COMPONENT: int = ...
        UNKNOWN_FIELD_NAME: int = ...
        UNKNOWN_UNIQUE_NAME: int = ...
        UNSUPPORTED_DIMENSIONS: int = ...
        URL_INVALID_SCHEME: int = ...
        URL_INVALID_TOP_LEVEL_DOMAIN: int = ...
        URL_MALFORMED: int = ...
        URL_NO_HOST: int = ...
        URL_NOT_EQUIVALENT: int = ...
        URL_HOST_NAME_TOO_LONG: int = ...
        URL_NO_SCHEME: int = ...
        URL_NO_TOP_LEVEL_DOMAIN: int = ...
        URL_PATH_NOT_ALLOWED: int = ...
        URL_PORT_NOT_ALLOWED: int = ...
        URL_QUERY_NOT_ALLOWED: int = ...
        URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG: int = ...
        USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE: int = ...
        INCONSISTENT_EXPANDABLE_SETTINGS: int = ...
        INVALID_FORMAT: int = ...
        INVALID_FIELD_TEXT: int = ...
        ELEMENT_NOT_PRESENT: int = ...
        IMAGE_ERROR: int = ...
        VALUE_NOT_IN_RANGE: int = ...
        FIELD_NOT_PRESENT: int = ...
        ADDRESS_NOT_COMPLETE: int = ...
        ADDRESS_INVALID: int = ...
        VIDEO_RETRIEVAL_ERROR: int = ...
        AUDIO_ERROR: int = ...
        INVALID_YOUTUBE_DISPLAY_URL: int = ...
        TOO_MANY_PRODUCT_IMAGES: int = ...
        TOO_MANY_PRODUCT_VIDEOS: int = ...
        INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE: int = ...
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int = ...
        DISALLOWED_NUMBER_TYPE: int = ...
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY: int = ...
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int = ...
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int = ...
        INVALID_CALL_CONVERSION_TYPE_ID: int = ...
        CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID: int = ...
        CANNOT_SET_PATH2_WITHOUT_PATH1: int = ...
        MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME: int = ...
        INCOMPATIBLE_WITH_RESTRICTION_TYPE: int = ...
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int = ...
        MISSING_IMAGE_OR_MEDIA_BUNDLE: int = ...
        PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN: int = ...
        PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE: int = ...
        PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE: int = ...
        PLACEHOLDER_DEFAULT_VALUE_MISSING: int = ...
        UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE: int = ...
        AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT: int = ...
        UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION: int = ...

class AdGroupAdErrorEnum:
    class AdGroupAdError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_GROUP_AD_LABEL_DOES_NOT_EXIST: int = ...
        AD_GROUP_AD_LABEL_ALREADY_EXISTS: int = ...
        AD_NOT_UNDER_ADGROUP: int = ...
        CANNOT_OPERATE_ON_REMOVED_ADGROUPAD: int = ...
        CANNOT_CREATE_DEPRECATED_ADS: int = ...
        CANNOT_CREATE_TEXT_ADS: int = ...
        EMPTY_FIELD: int = ...
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS: int = ...

class AdGroupAdRotationModeEnum:
    class AdGroupAdRotationMode(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        OPTIMIZE: int = ...
        ROTATE_FOREVER: int = ...

class AdGroupAdStatusEnum:
    class AdGroupAdStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        PAUSED: int = ...
        REMOVED: int = ...

class AdGroupBidModifierErrorEnum:
    class AdGroupBidModifierError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CRITERION_ID_NOT_SUPPORTED: int = ...
        CANNOT_OVERRIDE_OPTED_OUT_CAMPAIGN_CRITERION_BID_MODIFIER: int = ...

class AdGroupCriterionApprovalStatusEnum:
    class AdGroupCriterionApprovalStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        APPROVED: int = ...
        DISAPPROVED: int = ...
        PENDING_REVIEW: int = ...
        UNDER_REVIEW: int = ...

class AdGroupCriterionErrorEnum:
    class AdGroupCriterionError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST: int = ...
        AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS: int = ...
        CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION: int = ...
        TOO_MANY_OPERATIONS: int = ...
        CANT_UPDATE_NEGATIVE: int = ...
        CONCRETE_TYPE_REQUIRED: int = ...
        BID_INCOMPATIBLE_WITH_ADGROUP: int = ...
        CANNOT_TARGET_AND_EXCLUDE: int = ...
        ILLEGAL_URL: int = ...
        INVALID_KEYWORD_TEXT: int = ...
        INVALID_DESTINATION_URL: int = ...
        MISSING_DESTINATION_URL_TAG: int = ...
        KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM: int = ...
        INVALID_USER_STATUS: int = ...
        CANNOT_ADD_CRITERIA_TYPE: int = ...
        CANNOT_EXCLUDE_CRITERIA_TYPE: int = ...
        CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE: int = ...
        OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS: int = ...
        CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS: int = ...
        CANNOT_SET_WITHOUT_FINAL_URLS: int = ...
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST: int = ...
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST: int = ...
        CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS: int = ...
        CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST: int = ...
        CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS: int = ...
        CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE: int = ...
        FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE: int = ...
        FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE: int = ...
        INVALID_LISTING_GROUP_HIERARCHY: int = ...
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN: int = ...
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE: int = ...
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS: int = ...
        LISTING_GROUP_ALREADY_EXISTS: int = ...
        LISTING_GROUP_DOES_NOT_EXIST: int = ...
        LISTING_GROUP_CANNOT_BE_REMOVED: int = ...
        INVALID_LISTING_GROUP_TYPE: int = ...
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID: int = ...

class AdGroupCriterionStatusEnum:
    class AdGroupCriterionStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        PAUSED: int = ...
        REMOVED: int = ...

class AdGroupErrorEnum:
    class AdGroupError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DUPLICATE_ADGROUP_NAME: int = ...
        INVALID_ADGROUP_NAME: int = ...
        ADVERTISER_NOT_ON_CONTENT_NETWORK: int = ...
        BID_TOO_BIG: int = ...
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH: int = ...
        MISSING_ADGROUP_NAME: int = ...
        ADGROUP_LABEL_DOES_NOT_EXIST: int = ...
        ADGROUP_LABEL_ALREADY_EXISTS: int = ...
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP: int = ...
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE: int = ...
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY: int = ...
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING: int = ...

class AdGroupFeedErrorEnum:
    class AdGroupFeedError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int = ...
        CANNOT_CREATE_FOR_REMOVED_FEED: int = ...
        ADGROUP_FEED_ALREADY_EXISTS: int = ...
        CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED: int = ...
        INVALID_PLACEHOLDER_TYPE: int = ...
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE: int = ...
        NO_EXISTING_LOCATION_CUSTOMER_FEED: int = ...

class AdGroupStatusEnum:
    class AdGroupStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        PAUSED: int = ...
        REMOVED: int = ...

class AdGroupTypeEnum:
    class AdGroupType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SEARCH_STANDARD: int = ...
        DISPLAY_STANDARD: int = ...
        SHOPPING_PRODUCT_ADS: int = ...
        HOTEL_ADS: int = ...
        SHOPPING_SMART_ADS: int = ...
        VIDEO_BUMPER: int = ...
        VIDEO_TRUE_VIEW_IN_STREAM: int = ...
        VIDEO_TRUE_VIEW_IN_DISPLAY: int = ...
        VIDEO_NON_SKIPPABLE_IN_STREAM: int = ...
        VIDEO_OUTSTREAM: int = ...
        SEARCH_DYNAMIC_ADS: int = ...
        SHOPPING_COMPARISON_LISTING_ADS: int = ...
        PROMOTED_HOTEL_ADS: int = ...
        VIDEO_RESPONSIVE: int = ...

class AdNetworkTypeEnum:
    class AdNetworkType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SEARCH: int = ...
        SEARCH_PARTNERS: int = ...
        CONTENT: int = ...
        YOUTUBE_SEARCH: int = ...
        YOUTUBE_WATCH: int = ...
        MIXED: int = ...

class AdParameterErrorEnum:
    class AdParameterError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_GROUP_CRITERION_MUST_BE_KEYWORD: int = ...
        INVALID_INSERTION_TEXT_FORMAT: int = ...

class AdServingOptimizationStatusEnum:
    class AdServingOptimizationStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        OPTIMIZE: int = ...
        CONVERSION_OPTIMIZE: int = ...
        ROTATE: int = ...
        ROTATE_INDEFINITELY: int = ...
        UNAVAILABLE: int = ...

class AdSharingErrorEnum:
    class AdSharingError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_GROUP_ALREADY_CONTAINS_AD: int = ...
        INCOMPATIBLE_AD_UNDER_AD_GROUP: int = ...
        CANNOT_SHARE_INACTIVE_AD: int = ...

class AdStrengthEnum:
    class AdStrength(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PENDING: int = ...
        NO_ADS: int = ...
        POOR: int = ...
        AVERAGE: int = ...
        GOOD: int = ...
        EXCELLENT: int = ...

class AdTypeEnum:
    class AdType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        TEXT_AD: int = ...
        EXPANDED_TEXT_AD: int = ...
        CALL_ONLY_AD: int = ...
        EXPANDED_DYNAMIC_SEARCH_AD: int = ...
        HOTEL_AD: int = ...
        SHOPPING_SMART_AD: int = ...
        SHOPPING_PRODUCT_AD: int = ...
        VIDEO_AD: int = ...
        GMAIL_AD: int = ...
        IMAGE_AD: int = ...
        RESPONSIVE_SEARCH_AD: int = ...
        LEGACY_RESPONSIVE_DISPLAY_AD: int = ...
        APP_AD: int = ...
        LEGACY_APP_INSTALL_AD: int = ...
        RESPONSIVE_DISPLAY_AD: int = ...
        HTML5_UPLOAD_AD: int = ...
        DYNAMIC_HTML5_AD: int = ...
        APP_ENGAGEMENT_AD: int = ...
        SHOPPING_COMPARISON_LISTING_AD: int = ...
        VIDEO_RESPONSIVE_AD: int = ...

class AdvertisingChannelSubTypeEnum:
    class AdvertisingChannelSubType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SEARCH_MOBILE_APP: int = ...
        DISPLAY_MOBILE_APP: int = ...
        SEARCH_EXPRESS: int = ...
        DISPLAY_EXPRESS: int = ...
        SHOPPING_SMART_ADS: int = ...
        DISPLAY_GMAIL_AD: int = ...
        DISPLAY_SMART_CAMPAIGN: int = ...
        VIDEO_OUTSTREAM: int = ...
        VIDEO_ACTION: int = ...
        VIDEO_NON_SKIPPABLE: int = ...
        APP_CAMPAIGN: int = ...
        APP_CAMPAIGN_FOR_ENGAGEMENT: int = ...
        SHOPPING_COMPARISON_LISTING_ADS: int = ...

class AdvertisingChannelTypeEnum:
    class AdvertisingChannelType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SEARCH: int = ...
        DISPLAY: int = ...
        SHOPPING: int = ...
        HOTEL: int = ...
        VIDEO: int = ...
        MULTI_CHANNEL: int = ...

class AdxErrorEnum:
    class AdxError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        UNSUPPORTED_FEATURE: int = ...

class AffiliateLocationFeedRelationshipTypeEnum:
    class AffiliateLocationFeedRelationshipType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        GENERAL_RETAILER: int = ...

class AffiliateLocationPlaceholderFieldEnum:
    class AffiliateLocationPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BUSINESS_NAME: int = ...
        ADDRESS_LINE_1: int = ...
        ADDRESS_LINE_2: int = ...
        CITY: int = ...
        PROVINCE: int = ...
        POSTAL_CODE: int = ...
        COUNTRY_CODE: int = ...
        PHONE_NUMBER: int = ...
        LANGUAGE_CODE: int = ...
        CHAIN_ID: int = ...
        CHAIN_NAME: int = ...

class AgeRangeTypeEnum:
    class AgeRangeType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AGE_RANGE_18_24: int = ...
        AGE_RANGE_25_34: int = ...
        AGE_RANGE_35_44: int = ...
        AGE_RANGE_45_54: int = ...
        AGE_RANGE_55_64: int = ...
        AGE_RANGE_65_UP: int = ...
        AGE_RANGE_UNDETERMINED: int = ...

class AppCampaignAppStoreEnum:
    class AppCampaignAppStore(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        APPLE_APP_STORE: int = ...
        GOOGLE_APP_STORE: int = ...

class AppCampaignBiddingStrategyGoalTypeEnum:
    class AppCampaignBiddingStrategyGoalType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        OPTIMIZE_INSTALLS_TARGET_INSTALL_COST: int = ...
        OPTIMIZE_IN_APP_CONVERSIONS_TARGET_INSTALL_COST: int = ...
        OPTIMIZE_IN_APP_CONVERSIONS_TARGET_CONVERSION_COST: int = ...
        OPTIMIZE_RETURN_ON_ADVERTISING_SPEND: int = ...

class AppPaymentModelTypeEnum:
    class AppPaymentModelType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PAID: int = ...

class AppPlaceholderFieldEnum:
    class AppPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        STORE: int = ...
        ID: int = ...
        LINK_TEXT: int = ...
        URL: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        FINAL_URL_SUFFIX: int = ...

class AppStoreEnum:
    class AppStore(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        APPLE_ITUNES: int = ...
        GOOGLE_PLAY: int = ...

class AppUrlOperatingSystemTypeEnum:
    class AppUrlOperatingSystemType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        IOS: int = ...
        ANDROID: int = ...

class AssetErrorEnum:
    class AssetError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CUSTOMER_NOT_WHITELISTED_FOR_ASSET_TYPE: int = ...
        DUPLICATE_ASSET: int = ...
        DUPLICATE_ASSET_NAME: int = ...
        ASSET_DATA_IS_MISSING: int = ...
        CANNOT_MODIFY_ASSET_NAME: int = ...

class AssetFieldTypeEnum:
    class AssetFieldType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        HEADLINE: int = ...
        DESCRIPTION: int = ...
        MANDATORY_AD_TEXT: int = ...
        MARKETING_IMAGE: int = ...
        MEDIA_BUNDLE: int = ...
        YOUTUBE_VIDEO: int = ...

class AssetPerformanceLabelEnum:
    class AssetPerformanceLabel(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PENDING: int = ...
        LEARNING: int = ...
        LOW: int = ...
        GOOD: int = ...
        BEST: int = ...

class AssetTypeEnum:
    class AssetType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        YOUTUBE_VIDEO: int = ...
        MEDIA_BUNDLE: int = ...
        IMAGE: int = ...
        TEXT: int = ...

class AttributionModelEnum:
    class AttributionModel(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EXTERNAL: int = ...
        GOOGLE_ADS_LAST_CLICK: int = ...
        GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK: int = ...
        GOOGLE_SEARCH_ATTRIBUTION_LINEAR: int = ...
        GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY: int = ...
        GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED: int = ...
        GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN: int = ...

class AuthenticationErrorEnum:
    class AuthenticationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AUTHENTICATION_ERROR: int = ...
        CLIENT_CUSTOMER_ID_INVALID: int = ...
        CUSTOMER_NOT_FOUND: int = ...
        GOOGLE_ACCOUNT_DELETED: int = ...
        GOOGLE_ACCOUNT_COOKIE_INVALID: int = ...
        GOOGLE_ACCOUNT_AUTHENTICATION_FAILED: int = ...
        GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH: int = ...
        LOGIN_COOKIE_REQUIRED: int = ...
        NOT_ADS_USER: int = ...
        OAUTH_TOKEN_INVALID: int = ...
        OAUTH_TOKEN_EXPIRED: int = ...
        OAUTH_TOKEN_DISABLED: int = ...
        OAUTH_TOKEN_REVOKED: int = ...
        OAUTH_TOKEN_HEADER_INVALID: int = ...
        LOGIN_COOKIE_INVALID: int = ...
        USER_ID_INVALID: int = ...
        TWO_STEP_VERIFICATION_NOT_ENROLLED: int = ...
        ADVANCED_PROTECTION_NOT_ENROLLED: int = ...

class AuthorizationErrorEnum:
    class AuthorizationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        USER_PERMISSION_DENIED: int = ...
        DEVELOPER_TOKEN_NOT_WHITELISTED: int = ...
        DEVELOPER_TOKEN_PROHIBITED: int = ...
        PROJECT_DISABLED: int = ...
        AUTHORIZATION_ERROR: int = ...
        ACTION_NOT_PERMITTED: int = ...
        INCOMPLETE_SIGNUP: int = ...
        CUSTOMER_NOT_ENABLED: int = ...
        MISSING_TOS: int = ...
        DEVELOPER_TOKEN_NOT_APPROVED: int = ...
        INVALID_LOGIN_CUSTOMER_ID_SERVING_CUSTOMER_ID_COMBINATION: int = ...
        SERVICE_ACCESS_DENIED: int = ...

class BidModifierSourceEnum:
    class BidModifierSource(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CAMPAIGN: int = ...
        AD_GROUP: int = ...

class BiddingErrorEnum:
    class BiddingError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED: int = ...
        CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN: int = ...
        INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE: int = ...
        INVALID_BIDDING_STRATEGY_TYPE: int = ...
        INVALID_BID: int = ...
        BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE: int = ...
        CONVERSION_TRACKING_NOT_ENABLED: int = ...
        NOT_ENOUGH_CONVERSIONS: int = ...
        CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY: int = ...
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY: int = ...
        BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE: int = ...
        PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER: int = ...
        PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA: int = ...
        BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS: int = ...
        BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS: int = ...
        BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION: int = ...
        BID_TOO_SMALL: int = ...
        BID_TOO_BIG: int = ...
        BID_TOO_MANY_FRACTIONAL_DIGITS: int = ...
        INVALID_DOMAIN_NAME: int = ...
        NOT_COMPATIBLE_WITH_PAYMENT_MODE: int = ...
        NOT_COMPATIBLE_WITH_BUDGET_TYPE: int = ...
        NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE: int = ...
        BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET: int = ...

class BiddingSourceEnum:
    class BiddingSource(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CAMPAIGN_BIDDING_STRATEGY: int = ...
        AD_GROUP: int = ...
        AD_GROUP_CRITERION: int = ...

class BiddingStrategyErrorEnum:
    class BiddingStrategyError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DUPLICATE_NAME: int = ...
        CANNOT_CHANGE_BIDDING_STRATEGY_TYPE: int = ...
        CANNOT_REMOVE_ASSOCIATED_STRATEGY: int = ...
        BIDDING_STRATEGY_NOT_SUPPORTED: int = ...
        INCOMPATIBLE_BIDDING_STRATEGY_AND_BIDDING_STRATEGY_GOAL_TYPE: int = ...

class BiddingStrategyStatusEnum:
    class BiddingStrategyStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class BiddingStrategyTypeEnum:
    class BiddingStrategyType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        COMMISSION: int = ...
        ENHANCED_CPC: int = ...
        MANUAL_CPC: int = ...
        MANUAL_CPM: int = ...
        MANUAL_CPV: int = ...
        MAXIMIZE_CONVERSIONS: int = ...
        MAXIMIZE_CONVERSION_VALUE: int = ...
        PAGE_ONE_PROMOTED: int = ...
        PERCENT_CPC: int = ...
        TARGET_CPA: int = ...
        TARGET_CPM: int = ...
        TARGET_IMPRESSION_SHARE: int = ...
        TARGET_OUTRANK_SHARE: int = ...
        TARGET_ROAS: int = ...
        TARGET_SPEND: int = ...

class BillingSetupErrorEnum:
    class BillingSetupError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CANNOT_USE_EXISTING_AND_NEW_ACCOUNT: int = ...
        CANNOT_REMOVE_STARTED_BILLING_SETUP: int = ...
        CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT: int = ...
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS: int = ...
        INVALID_PAYMENTS_ACCOUNT: int = ...
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY: int = ...
        INVALID_START_TIME_TYPE: int = ...
        THIRD_PARTY_ALREADY_HAS_BILLING: int = ...
        BILLING_SETUP_IN_PROGRESS: int = ...
        NO_SIGNUP_PERMISSION: int = ...
        CHANGE_OF_BILL_TO_IN_PROGRESS: int = ...
        PAYMENTS_PROFILE_NOT_FOUND: int = ...
        PAYMENTS_ACCOUNT_NOT_FOUND: int = ...
        PAYMENTS_PROFILE_INELIGIBLE: int = ...
        PAYMENTS_ACCOUNT_INELIGIBLE: int = ...
        CUSTOMER_NEEDS_INTERNAL_APPROVAL: int = ...
        PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH: int = ...

class BillingSetupStatusEnum:
    class BillingSetupStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PENDING: int = ...
        APPROVED_HELD: int = ...
        APPROVED: int = ...
        CANCELLED: int = ...

class BrandSafetySuitabilityEnum:
    class BrandSafetySuitability(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EXPANDED_INVENTORY: int = ...
        STANDARD_INVENTORY: int = ...
        LIMITED_INVENTORY: int = ...

class BudgetDeliveryMethodEnum:
    class BudgetDeliveryMethod(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        STANDARD: int = ...
        ACCELERATED: int = ...

class BudgetPeriodEnum:
    class BudgetPeriod(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DAILY: int = ...

class BudgetStatusEnum:
    class BudgetStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class BudgetTypeEnum:
    class BudgetType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        STANDARD: int = ...
        HOTEL_ADS_COMMISSION: int = ...
        FIXED_CPA: int = ...

class CallConversionReportingStateEnum:
    class CallConversionReportingState(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DISABLED: int = ...
        USE_ACCOUNT_LEVEL_CALL_CONVERSION_ACTION: int = ...
        USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION: int = ...

class CallPlaceholderFieldEnum:
    class CallPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PHONE_NUMBER: int = ...
        COUNTRY_CODE: int = ...
        TRACKED: int = ...
        CONVERSION_TYPE_ID: int = ...
        CONVERSION_REPORTING_STATE: int = ...

class CalloutPlaceholderFieldEnum:
    class CalloutPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CALLOUT_TEXT: int = ...

class CampaignBudgetErrorEnum:
    class CampaignBudgetError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CAMPAIGN_BUDGET_CANNOT_BE_SHARED: int = ...
        CAMPAIGN_BUDGET_REMOVED: int = ...
        CAMPAIGN_BUDGET_IN_USE: int = ...
        CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE: int = ...
        CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET: int = ...
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED: int = ...
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME: int = ...
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED: int = ...
        CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS: int = ...
        DUPLICATE_NAME: int = ...
        MONEY_AMOUNT_IN_WRONG_CURRENCY: int = ...
        MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC: int = ...
        MONEY_AMOUNT_TOO_LARGE: int = ...
        NEGATIVE_MONEY_AMOUNT: int = ...
        NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT: int = ...

class CampaignCriterionErrorEnum:
    class CampaignCriterionError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CONCRETE_TYPE_REQUIRED: int = ...
        INVALID_PLACEMENT_URL: int = ...
        CANNOT_EXCLUDE_CRITERIA_TYPE: int = ...
        CANNOT_SET_STATUS_FOR_CRITERIA_TYPE: int = ...
        CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA: int = ...
        CANNOT_TARGET_AND_EXCLUDE: int = ...
        TOO_MANY_OPERATIONS: int = ...
        OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE: int = ...
        SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL: int = ...
        CANNOT_ADD_EXISTING_FIELD: int = ...
        CANNOT_UPDATE_NEGATIVE_CRITERION: int = ...

class CampaignCriterionStatusEnum:
    class CampaignCriterionStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        PAUSED: int = ...
        REMOVED: int = ...

class CampaignDraftErrorEnum:
    class CampaignDraftError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DUPLICATE_DRAFT_NAME: int = ...
        INVALID_STATUS_TRANSITION_FROM_REMOVED: int = ...
        INVALID_STATUS_TRANSITION_FROM_PROMOTED: int = ...
        INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED: int = ...
        CUSTOMER_CANNOT_CREATE_DRAFT: int = ...
        CAMPAIGN_CANNOT_CREATE_DRAFT: int = ...
        INVALID_DRAFT_CHANGE: int = ...
        INVALID_STATUS_TRANSITION: int = ...
        MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED: int = ...
        LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY: int = ...

class CampaignDraftStatusEnum:
    class CampaignDraftStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PROPOSED: int = ...
        REMOVED: int = ...
        PROMOTING: int = ...
        PROMOTED: int = ...
        PROMOTE_FAILED: int = ...

class CampaignErrorEnum:
    class CampaignError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CANNOT_TARGET_CONTENT_NETWORK: int = ...
        CANNOT_TARGET_SEARCH_NETWORK: int = ...
        CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH: int = ...
        CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN: int = ...
        CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK: int = ...
        CANNOT_TARGET_PARTNER_SEARCH_NETWORK: int = ...
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY: int = ...
        CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS: int = ...
        CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN: int = ...
        DUPLICATE_CAMPAIGN_NAME: int = ...
        INCOMPATIBLE_CAMPAIGN_FIELD: int = ...
        INVALID_CAMPAIGN_NAME: int = ...
        INVALID_AD_SERVING_OPTIMIZATION_STATUS: int = ...
        INVALID_TRACKING_URL: int = ...
        CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING: int = ...
        MAX_IMPRESSIONS_NOT_IN_RANGE: int = ...
        TIME_UNIT_NOT_SUPPORTED: int = ...
        INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED: int = ...
        BUDGET_CANNOT_BE_SHARED: int = ...
        CAMPAIGN_CANNOT_USE_SHARED_BUDGET: int = ...
        CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS: int = ...
        CAMPAIGN_LABEL_DOES_NOT_EXIST: int = ...
        CAMPAIGN_LABEL_ALREADY_EXISTS: int = ...
        MISSING_SHOPPING_SETTING: int = ...
        INVALID_SHOPPING_SALES_COUNTRY: int = ...
        ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE: int = ...
        INVALID_ADVERTISING_CHANNEL_SUB_TYPE: int = ...
        AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED: int = ...
        CANNOT_SET_AD_ROTATION_MODE: int = ...
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED: int = ...
        CANNOT_SET_DATE_TO_PAST: int = ...
        MISSING_HOTEL_CUSTOMER_LINK: int = ...
        INVALID_HOTEL_CUSTOMER_LINK: int = ...
        MISSING_HOTEL_SETTING: int = ...
        CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP: int = ...
        APP_NOT_FOUND: int = ...
        SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE: int = ...
        MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS: int = ...
        INSUFFICIENT_APP_INSTALLS_COUNT: int = ...
        SENSITIVE_CATEGORY_APP: int = ...

class CampaignExperimentErrorEnum:
    class CampaignExperimentError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DUPLICATE_NAME: int = ...
        INVALID_TRANSITION: int = ...
        CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET: int = ...
        CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN: int = ...
        CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT: int = ...
        CUSTOMER_CANNOT_CREATE_EXPERIMENT: int = ...
        CAMPAIGN_CANNOT_CREATE_EXPERIMENT: int = ...
        EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP: int = ...
        EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION: int = ...
        CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS: int = ...

class CampaignExperimentStatusEnum:
    class CampaignExperimentStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INITIALIZING: int = ...
        INITIALIZATION_FAILED: int = ...
        ENABLED: int = ...
        GRADUATED: int = ...
        REMOVED: int = ...
        PROMOTING: int = ...
        PROMOTION_FAILED: int = ...
        PROMOTED: int = ...
        ENDED_MANUALLY: int = ...

class CampaignExperimentTrafficSplitTypeEnum:
    class CampaignExperimentTrafficSplitType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        RANDOM_QUERY: int = ...
        COOKIE: int = ...

class CampaignExperimentTypeEnum:
    class CampaignExperimentType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BASE: int = ...
        DRAFT: int = ...
        EXPERIMENT: int = ...

class CampaignFeedErrorEnum:
    class CampaignFeedError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int = ...
        CANNOT_CREATE_FOR_REMOVED_FEED: int = ...
        CANNOT_CREATE_ALREADY_EXISTING_CAMPAIGN_FEED: int = ...
        CANNOT_MODIFY_REMOVED_CAMPAIGN_FEED: int = ...
        INVALID_PLACEHOLDER_TYPE: int = ...
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE: int = ...
        NO_EXISTING_LOCATION_CUSTOMER_FEED: int = ...

class CampaignServingStatusEnum:
    class CampaignServingStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SERVING: int = ...
        NONE: int = ...
        ENDED: int = ...
        PENDING: int = ...
        SUSPENDED: int = ...

class CampaignSharedSetErrorEnum:
    class CampaignSharedSetError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SHARED_SET_ACCESS_DENIED: int = ...

class CampaignSharedSetStatusEnum:
    class CampaignSharedSetStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class CampaignStatusEnum:
    class CampaignStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        PAUSED: int = ...
        REMOVED: int = ...

class ChangeStatusErrorEnum:
    class ChangeStatusError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        START_DATE_TOO_OLD: int = ...

class ChangeStatusOperationEnum:
    class ChangeStatusOperation(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ADDED: int = ...
        CHANGED: int = ...
        REMOVED: int = ...

class ChangeStatusResourceTypeEnum:
    class ChangeStatusResourceType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_GROUP: int = ...
        AD_GROUP_AD: int = ...
        AD_GROUP_CRITERION: int = ...
        CAMPAIGN: int = ...
        CAMPAIGN_CRITERION: int = ...
        FEED: int = ...
        FEED_ITEM: int = ...
        AD_GROUP_FEED: int = ...
        CAMPAIGN_FEED: int = ...
        AD_GROUP_BID_MODIFIER: int = ...

class ClickTypeEnum:
    class ClickType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        APP_DEEPLINK: int = ...
        BREADCRUMBS: int = ...
        BROADBAND_PLAN: int = ...
        CALL_TRACKING: int = ...
        CALLS: int = ...
        CLICK_ON_ENGAGEMENT_AD: int = ...
        GET_DIRECTIONS: int = ...
        LOCATION_EXPANSION: int = ...
        LOCATION_FORMAT_CALL: int = ...
        LOCATION_FORMAT_DIRECTIONS: int = ...
        LOCATION_FORMAT_IMAGE: int = ...
        LOCATION_FORMAT_LANDING_PAGE: int = ...
        LOCATION_FORMAT_MAP: int = ...
        LOCATION_FORMAT_STORE_INFO: int = ...
        LOCATION_FORMAT_TEXT: int = ...
        MOBILE_CALL_TRACKING: int = ...
        OFFER_PRINTS: int = ...
        OTHER: int = ...
        PRODUCT_EXTENSION_CLICKS: int = ...
        PRODUCT_LISTING_AD_CLICKS: int = ...
        SITELINKS: int = ...
        STORE_LOCATOR: int = ...
        URL_CLICKS: int = ...
        VIDEO_APP_STORE_CLICKS: int = ...
        VIDEO_CALL_TO_ACTION_CLICKS: int = ...
        VIDEO_CARD_ACTION_HEADLINE_CLICKS: int = ...
        VIDEO_END_CAP_CLICKS: int = ...
        VIDEO_WEBSITE_CLICKS: int = ...
        VISUAL_SITELINKS: int = ...
        WIRELESS_PLAN: int = ...
        PRODUCT_LISTING_AD_LOCAL: int = ...
        PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL: int = ...
        PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE: int = ...
        PRODUCT_LISTING_ADS_COUPON: int = ...
        PRODUCT_LISTING_AD_TRANSACTABLE: int = ...
        PRODUCT_AD_APP_DEEPLINK: int = ...
        SHOWCASE_AD_CATEGORY_LINK: int = ...
        SHOWCASE_AD_LOCAL_STOREFRONT_LINK: int = ...
        SHOWCASE_AD_ONLINE_PRODUCT_LINK: int = ...
        SHOWCASE_AD_LOCAL_PRODUCT_LINK: int = ...
        PROMOTION_EXTENSION: int = ...
        SWIPEABLE_GALLERY_AD_HEADLINE: int = ...
        SWIPEABLE_GALLERY_AD_SWIPES: int = ...
        SWIPEABLE_GALLERY_AD_SEE_MORE: int = ...
        SWIPEABLE_GALLERY_AD_SITELINK_ONE: int = ...
        SWIPEABLE_GALLERY_AD_SITELINK_TWO: int = ...
        SWIPEABLE_GALLERY_AD_SITELINK_THREE: int = ...
        SWIPEABLE_GALLERY_AD_SITELINK_FOUR: int = ...
        SWIPEABLE_GALLERY_AD_SITELINK_FIVE: int = ...
        HOTEL_PRICE: int = ...
        PRICE_EXTENSION: int = ...
        HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION: int = ...
        SHOPPING_COMPARISON_LISTING: int = ...

class CollectionSizeErrorEnum:
    class CollectionSizeError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        TOO_FEW: int = ...
        TOO_MANY: int = ...

class ContentLabelTypeEnum:
    class ContentLabelType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SEXUALLY_SUGGESTIVE: int = ...
        BELOW_THE_FOLD: int = ...
        PARKED_DOMAIN: int = ...
        JUVENILE: int = ...
        PROFANITY: int = ...
        TRAGEDY: int = ...
        VIDEO: int = ...
        VIDEO_RATING_DV_G: int = ...
        VIDEO_RATING_DV_PG: int = ...
        VIDEO_RATING_DV_T: int = ...
        VIDEO_RATING_DV_MA: int = ...
        VIDEO_NOT_YET_RATED: int = ...
        EMBEDDED_VIDEO: int = ...
        LIVE_STREAMING_VIDEO: int = ...
        SOCIAL_ISSUES: int = ...

class ContextErrorEnum:
    class ContextError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        OPERATION_NOT_PERMITTED_FOR_CONTEXT: int = ...
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE: int = ...

class ConversionActionCategoryEnum:
    class ConversionActionCategory(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DEFAULT: int = ...
        PAGE_VIEW: int = ...
        PURCHASE: int = ...
        SIGNUP: int = ...
        LEAD: int = ...
        DOWNLOAD: int = ...
        ADD_TO_CART: int = ...
        BEGIN_CHECKOUT: int = ...
        SUBSCRIBE_PAID: int = ...
        PHONE_CALL_LEAD: int = ...
        IMPORTED_LEAD: int = ...
        SUBMIT_LEAD_FORM: int = ...
        BOOK_APPOINTMENT: int = ...
        REQUEST_QUOTE: int = ...
        GET_DIRECTIONS: int = ...
        OUTBOUND_CLICK: int = ...
        CONTACT: int = ...
        ENGAGEMENT: int = ...
        STORE_VISIT: int = ...
        STORE_SALE: int = ...

class ConversionActionCountingTypeEnum:
    class ConversionActionCountingType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ONE_PER_CLICK: int = ...
        MANY_PER_CLICK: int = ...

class ConversionActionErrorEnum:
    class ConversionActionError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DUPLICATE_NAME: int = ...
        DUPLICATE_APP_ID: int = ...
        TWO_CONVERSION_ACTIONS_BIDDING_ON_SAME_APP_DOWNLOAD: int = ...
        BIDDING_ON_SAME_APP_DOWNLOAD_AS_GLOBAL_ACTION: int = ...
        DATA_DRIVEN_MODEL_WAS_NEVER_GENERATED: int = ...
        DATA_DRIVEN_MODEL_EXPIRED: int = ...
        DATA_DRIVEN_MODEL_STALE: int = ...
        DATA_DRIVEN_MODEL_UNKNOWN: int = ...

class ConversionActionStatusEnum:
    class ConversionActionStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...
        HIDDEN: int = ...

class ConversionActionTypeEnum:
    class ConversionActionType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_CALL: int = ...
        CLICK_TO_CALL: int = ...
        GOOGLE_PLAY_DOWNLOAD: int = ...
        GOOGLE_PLAY_IN_APP_PURCHASE: int = ...
        UPLOAD_CALLS: int = ...
        UPLOAD_CLICKS: int = ...
        WEBPAGE: int = ...
        WEBSITE_CALL: int = ...

class ConversionAdjustmentTypeEnum:
    class ConversionAdjustmentType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        RETRACTION: int = ...
        RESTATEMENT: int = ...

class ConversionAdjustmentUploadErrorEnum:
    class ConversionAdjustmentUploadError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        TOO_RECENT_CONVERSION_ACTION: int = ...
        INVALID_CONVERSION_ACTION: int = ...
        CONVERSION_ALREADY_RETRACTED: int = ...
        CONVERSION_NOT_FOUND: int = ...
        CONVERSION_EXPIRED: int = ...
        ADJUSTMENT_PRECEDES_CONVERSION: int = ...
        MORE_RECENT_RESTATEMENT_FOUND: int = ...
        TOO_RECENT_CONVERSION: int = ...
        CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE: int = ...
        TOO_MANY_ADJUSTMENTS_IN_REQUEST: int = ...
        TOO_MANY_ADJUSTMENTS: int = ...

class ConversionAttributionEventTypeEnum:
    class ConversionAttributionEventType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        IMPRESSION: int = ...
        INTERACTION: int = ...

class ConversionLagBucketEnum:
    class ConversionLagBucket(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LESS_THAN_ONE_DAY: int = ...
        ONE_TO_TWO_DAYS: int = ...
        TWO_TO_THREE_DAYS: int = ...
        THREE_TO_FOUR_DAYS: int = ...
        FOUR_TO_FIVE_DAYS: int = ...
        FIVE_TO_SIX_DAYS: int = ...
        SIX_TO_SEVEN_DAYS: int = ...
        SEVEN_TO_EIGHT_DAYS: int = ...
        EIGHT_TO_NINE_DAYS: int = ...
        NINE_TO_TEN_DAYS: int = ...
        TEN_TO_ELEVEN_DAYS: int = ...
        ELEVEN_TO_TWELVE_DAYS: int = ...
        TWELVE_TO_THIRTEEN_DAYS: int = ...
        THIRTEEN_TO_FOURTEEN_DAYS: int = ...
        FOURTEEN_TO_TWENTY_ONE_DAYS: int = ...
        TWENTY_ONE_TO_THIRTY_DAYS: int = ...
        THIRTY_TO_FORTY_FIVE_DAYS: int = ...
        FORTY_FIVE_TO_SIXTY_DAYS: int = ...
        SIXTY_TO_NINETY_DAYS: int = ...

class ConversionOrAdjustmentLagBucketEnum:
    class ConversionOrAdjustmentLagBucket(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CONVERSION_LESS_THAN_ONE_DAY: int = ...
        CONVERSION_ONE_TO_TWO_DAYS: int = ...
        CONVERSION_TWO_TO_THREE_DAYS: int = ...
        CONVERSION_THREE_TO_FOUR_DAYS: int = ...
        CONVERSION_FOUR_TO_FIVE_DAYS: int = ...
        CONVERSION_FIVE_TO_SIX_DAYS: int = ...
        CONVERSION_SIX_TO_SEVEN_DAYS: int = ...
        CONVERSION_SEVEN_TO_EIGHT_DAYS: int = ...
        CONVERSION_EIGHT_TO_NINE_DAYS: int = ...
        CONVERSION_NINE_TO_TEN_DAYS: int = ...
        CONVERSION_TEN_TO_ELEVEN_DAYS: int = ...
        CONVERSION_ELEVEN_TO_TWELVE_DAYS: int = ...
        CONVERSION_TWELVE_TO_THIRTEEN_DAYS: int = ...
        CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS: int = ...
        CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS: int = ...
        CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS: int = ...
        CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS: int = ...
        CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS: int = ...
        CONVERSION_SIXTY_TO_NINETY_DAYS: int = ...
        ADJUSTMENT_LESS_THAN_ONE_DAY: int = ...
        ADJUSTMENT_ONE_TO_TWO_DAYS: int = ...
        ADJUSTMENT_TWO_TO_THREE_DAYS: int = ...
        ADJUSTMENT_THREE_TO_FOUR_DAYS: int = ...
        ADJUSTMENT_FOUR_TO_FIVE_DAYS: int = ...
        ADJUSTMENT_FIVE_TO_SIX_DAYS: int = ...
        ADJUSTMENT_SIX_TO_SEVEN_DAYS: int = ...
        ADJUSTMENT_SEVEN_TO_EIGHT_DAYS: int = ...
        ADJUSTMENT_EIGHT_TO_NINE_DAYS: int = ...
        ADJUSTMENT_NINE_TO_TEN_DAYS: int = ...
        ADJUSTMENT_TEN_TO_ELEVEN_DAYS: int = ...
        ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS: int = ...
        ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS: int = ...
        ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS: int = ...
        ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS: int = ...
        ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS: int = ...
        ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS: int = ...
        ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS: int = ...
        ADJUSTMENT_SIXTY_TO_NINETY_DAYS: int = ...
        ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS: int = ...
        CONVERSION_UNKNOWN: int = ...
        ADJUSTMENT_UNKNOWN: int = ...

class ConversionUploadErrorEnum:
    class ConversionUploadError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        TOO_MANY_CONVERSIONS_IN_REQUEST: int = ...
        UNPARSEABLE_GCLID: int = ...
        CONVERSION_PRECEDES_GCLID: int = ...
        EXPIRED_GCLID: int = ...
        TOO_RECENT_GCLID: int = ...
        GCLID_NOT_FOUND: int = ...
        UNAUTHORIZED_CUSTOMER: int = ...
        INVALID_CONVERSION_ACTION: int = ...
        TOO_RECENT_CONVERSION_ACTION: int = ...
        CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME: int = ...
        EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int = ...
        EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int = ...
        ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int = ...
        ORDER_ID_ALREADY_IN_USE: int = ...
        DUPLICATE_ORDER_ID: int = ...
        TOO_RECENT_CALL: int = ...
        EXPIRED_CALL: int = ...
        CALL_NOT_FOUND: int = ...
        CONVERSION_PRECEDES_CALL: int = ...
        CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME: int = ...
        UNPARSEABLE_CALLERS_PHONE_NUMBER: int = ...

class CountryCodeErrorEnum:
    class CountryCodeError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_COUNTRY_CODE: int = ...

class CriterionCategoryChannelAvailabilityModeEnum:
    class CriterionCategoryChannelAvailabilityMode(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ALL_CHANNELS: int = ...
        CHANNEL_TYPE_AND_ALL_SUBTYPES: int = ...
        CHANNEL_TYPE_AND_SUBSET_SUBTYPES: int = ...

class CriterionCategoryLocaleAvailabilityModeEnum:
    class CriterionCategoryLocaleAvailabilityMode(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ALL_LOCALES: int = ...
        COUNTRY_AND_ALL_LANGUAGES: int = ...
        LANGUAGE_AND_ALL_COUNTRIES: int = ...
        COUNTRY_AND_LANGUAGE: int = ...

class CriterionErrorEnum:
    class CriterionError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CONCRETE_TYPE_REQUIRED: int = ...
        INVALID_EXCLUDED_CATEGORY: int = ...
        INVALID_KEYWORD_TEXT: int = ...
        KEYWORD_TEXT_TOO_LONG: int = ...
        KEYWORD_HAS_TOO_MANY_WORDS: int = ...
        KEYWORD_HAS_INVALID_CHARS: int = ...
        INVALID_PLACEMENT_URL: int = ...
        INVALID_USER_LIST: int = ...
        INVALID_USER_INTEREST: int = ...
        INVALID_FORMAT_FOR_PLACEMENT_URL: int = ...
        PLACEMENT_URL_IS_TOO_LONG: int = ...
        PLACEMENT_URL_HAS_ILLEGAL_CHAR: int = ...
        PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE: int = ...
        PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION: int = ...
        INVALID_TOPIC_PATH: int = ...
        INVALID_YOUTUBE_CHANNEL_ID: int = ...
        INVALID_YOUTUBE_VIDEO_ID: int = ...
        YOUTUBE_VERTICAL_CHANNEL_DEPRECATED: int = ...
        YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED: int = ...
        YOUTUBE_URL_UNSUPPORTED: int = ...
        CANNOT_EXCLUDE_CRITERIA_TYPE: int = ...
        CANNOT_ADD_CRITERIA_TYPE: int = ...
        INVALID_PRODUCT_FILTER: int = ...
        PRODUCT_FILTER_TOO_LONG: int = ...
        CANNOT_EXCLUDE_SIMILAR_USER_LIST: int = ...
        CANNOT_ADD_CLOSED_USER_LIST: int = ...
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS: int = ...
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS: int = ...
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS: int = ...
        CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS: int = ...
        CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS: int = ...
        CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE: int = ...
        INVALID_CUSTOM_AFFINITY: int = ...
        INVALID_CUSTOM_INTENT: int = ...
        INVALID_IP_ADDRESS: int = ...
        INVALID_IP_FORMAT: int = ...
        INVALID_MOBILE_APP: int = ...
        INVALID_MOBILE_APP_CATEGORY: int = ...
        INVALID_CRITERION_ID: int = ...
        CANNOT_TARGET_CRITERION: int = ...
        CANNOT_TARGET_OBSOLETE_CRITERION: int = ...
        CRITERION_ID_AND_TYPE_MISMATCH: int = ...
        INVALID_PROXIMITY_RADIUS: int = ...
        INVALID_PROXIMITY_RADIUS_UNITS: int = ...
        INVALID_STREETADDRESS_LENGTH: int = ...
        INVALID_CITYNAME_LENGTH: int = ...
        INVALID_REGIONCODE_LENGTH: int = ...
        INVALID_REGIONNAME_LENGTH: int = ...
        INVALID_POSTALCODE_LENGTH: int = ...
        INVALID_COUNTRY_CODE: int = ...
        INVALID_LATITUDE: int = ...
        INVALID_LONGITUDE: int = ...
        PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL: int = ...
        INVALID_PROXIMITY_ADDRESS: int = ...
        INVALID_USER_DOMAIN_NAME: int = ...
        CRITERION_PARAMETER_TOO_LONG: int = ...
        AD_SCHEDULE_TIME_INTERVALS_OVERLAP: int = ...
        AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS: int = ...
        AD_SCHEDULE_INVALID_TIME_INTERVAL: int = ...
        AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT: int = ...
        AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS: int = ...
        CANNOT_BID_MODIFY_CRITERION_TYPE: int = ...
        CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT: int = ...
        CANNOT_BID_MODIFY_NEGATIVE_CRITERION: int = ...
        BID_MODIFIER_ALREADY_EXISTS: int = ...
        FEED_ID_NOT_ALLOWED: int = ...
        ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE: int = ...
        CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY: int = ...
        CANNOT_EXCLUDE_CRITERION: int = ...
        CANNOT_REMOVE_CRITERION: int = ...
        PRODUCT_SCOPE_TOO_LONG: int = ...
        PRODUCT_SCOPE_TOO_MANY_DIMENSIONS: int = ...
        PRODUCT_PARTITION_TOO_LONG: int = ...
        PRODUCT_PARTITION_TOO_MANY_DIMENSIONS: int = ...
        INVALID_PRODUCT_DIMENSION: int = ...
        INVALID_PRODUCT_DIMENSION_TYPE: int = ...
        INVALID_PRODUCT_BIDDING_CATEGORY: int = ...
        MISSING_SHOPPING_SETTING: int = ...
        INVALID_MATCHING_FUNCTION: int = ...
        LOCATION_FILTER_NOT_ALLOWED: int = ...
        INVALID_FEED_FOR_LOCATION_FILTER: int = ...
        LOCATION_FILTER_INVALID: int = ...
        CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP: int = ...
        HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION: int = ...
        HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION: int = ...
        FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING: int = ...
        INVALID_WEBPAGE_CONDITION: int = ...
        INVALID_WEBPAGE_CONDITION_URL: int = ...
        WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY: int = ...
        WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL: int = ...
        WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS: int = ...
        WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING: int = ...
        WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX: int = ...
        WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX: int = ...
        WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED: int = ...
        WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION: int = ...
        WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP: int = ...
        CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS: int = ...

class CriterionSystemServingStatusEnum:
    class CriterionSystemServingStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ELIGIBLE: int = ...
        RARELY_SERVED: int = ...

class CriterionTypeEnum:
    class CriterionType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        KEYWORD: int = ...
        PLACEMENT: int = ...
        MOBILE_APP_CATEGORY: int = ...
        MOBILE_APPLICATION: int = ...
        DEVICE: int = ...
        LOCATION: int = ...
        LISTING_GROUP: int = ...
        AD_SCHEDULE: int = ...
        AGE_RANGE: int = ...
        GENDER: int = ...
        INCOME_RANGE: int = ...
        PARENTAL_STATUS: int = ...
        YOUTUBE_VIDEO: int = ...
        YOUTUBE_CHANNEL: int = ...
        USER_LIST: int = ...
        PROXIMITY: int = ...
        TOPIC: int = ...
        LISTING_SCOPE: int = ...
        LANGUAGE: int = ...
        IP_BLOCK: int = ...
        CONTENT_LABEL: int = ...
        CARRIER: int = ...
        USER_INTEREST: int = ...
        WEBPAGE: int = ...
        OPERATING_SYSTEM_VERSION: int = ...
        APP_PAYMENT_MODEL: int = ...
        MOBILE_DEVICE: int = ...
        CUSTOM_AFFINITY: int = ...
        CUSTOM_INTENT: int = ...
        LOCATION_GROUP: int = ...

class CurrencyCodeErrorEnum:
    class CurrencyCodeError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        UNSUPPORTED: int = ...

class CustomInterestErrorEnum:
    class CustomInterestError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NAME_ALREADY_USED: int = ...
        CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE: int = ...
        TYPE_AND_PARAMETER_NOT_FOUND: int = ...
        TYPE_AND_PARAMETER_ALREADY_EXISTED: int = ...
        INVALID_CUSTOM_INTEREST_MEMBER_TYPE: int = ...
        CANNOT_REMOVE_WHILE_IN_USE: int = ...
        CANNOT_CHANGE_TYPE: int = ...

class CustomInterestMemberTypeEnum:
    class CustomInterestMemberType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        KEYWORD: int = ...
        URL: int = ...

class CustomInterestStatusEnum:
    class CustomInterestStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class CustomInterestTypeEnum:
    class CustomInterestType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CUSTOM_AFFINITY: int = ...
        CUSTOM_INTENT: int = ...

class CustomPlaceholderFieldEnum:
    class CustomPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ID: int = ...
        ID2: int = ...
        ITEM_TITLE: int = ...
        ITEM_SUBTITLE: int = ...
        ITEM_DESCRIPTION: int = ...
        ITEM_ADDRESS: int = ...
        PRICE: int = ...
        FORMATTED_PRICE: int = ...
        SALE_PRICE: int = ...
        FORMATTED_SALE_PRICE: int = ...
        IMAGE_URL: int = ...
        ITEM_CATEGORY: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        CONTEXTUAL_KEYWORDS: int = ...
        ANDROID_APP_LINK: int = ...
        SIMILAR_IDS: int = ...
        IOS_APP_LINK: int = ...
        IOS_APP_STORE_ID: int = ...

class CustomerClientLinkErrorEnum:
    class CustomerClientLinkError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CLIENT_ALREADY_INVITED_BY_THIS_MANAGER: int = ...
        CLIENT_ALREADY_MANAGED_IN_HIERARCHY: int = ...
        CYCLIC_LINK_NOT_ALLOWED: int = ...
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS: int = ...
        CLIENT_HAS_TOO_MANY_INVITATIONS: int = ...
        CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS: int = ...
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER: int = ...

class CustomerErrorEnum:
    class CustomerError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        STATUS_CHANGE_DISALLOWED: int = ...
        ACCOUNT_NOT_SET_UP: int = ...

class CustomerFeedErrorEnum:
    class CustomerFeedError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int = ...
        CANNOT_CREATE_FOR_REMOVED_FEED: int = ...
        CANNOT_CREATE_ALREADY_EXISTING_CUSTOMER_FEED: int = ...
        CANNOT_MODIFY_REMOVED_CUSTOMER_FEED: int = ...
        INVALID_PLACEHOLDER_TYPE: int = ...
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE: int = ...
        PLACEHOLDER_TYPE_NOT_ALLOWED_ON_CUSTOMER_FEED: int = ...

class CustomerManagerLinkErrorEnum:
    class CustomerManagerLinkError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NO_PENDING_INVITE: int = ...
        SAME_CLIENT_MORE_THAN_ONCE_PER_CALL: int = ...
        MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS: int = ...
        CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER: int = ...
        CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER: int = ...
        CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER: int = ...
        CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT: int = ...
        DUPLICATE_CHILD_FOUND: int = ...
        TEST_ACCOUNT_LINKS_TOO_MANY_CHILD_ACCOUNTS: int = ...

class CustomerMatchUploadKeyTypeEnum:
    class CustomerMatchUploadKeyType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CONTACT_INFO: int = ...
        CRM_ID: int = ...
        MOBILE_ADVERTISING_ID: int = ...

class CustomerPayPerConversionEligibilityFailureReasonEnum:
    class CustomerPayPerConversionEligibilityFailureReason(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NOT_ENOUGH_CONVERSIONS: int = ...
        CONVERSION_LAG_TOO_HIGH: int = ...
        HAS_CAMPAIGN_WITH_SHARED_BUDGET: int = ...
        HAS_UPLOAD_CLICKS_CONVERSION: int = ...
        AVERAGE_DAILY_SPEND_TOO_HIGH: int = ...
        ANALYSIS_NOT_COMPLETE: int = ...
        OTHER: int = ...

class DataDrivenModelStatusEnum:
    class DataDrivenModelStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AVAILABLE: int = ...
        STALE: int = ...
        EXPIRED: int = ...
        NEVER_GENERATED: int = ...

class DatabaseErrorEnum:
    class DatabaseError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CONCURRENT_MODIFICATION: int = ...
        DATA_CONSTRAINT_VIOLATION: int = ...
        REQUEST_TOO_LARGE: int = ...

class DateErrorEnum:
    class DateError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_FIELD_VALUES_IN_DATE: int = ...
        INVALID_FIELD_VALUES_IN_DATE_TIME: int = ...
        INVALID_STRING_DATE: int = ...
        INVALID_STRING_DATE_TIME_MICROS: int = ...
        INVALID_STRING_DATE_TIME_SECONDS: int = ...
        INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET: int = ...
        EARLIER_THAN_MINIMUM_DATE: int = ...
        LATER_THAN_MAXIMUM_DATE: int = ...
        DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE: int = ...
        DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL: int = ...

class DateRangeErrorEnum:
    class DateRangeError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_DATE: int = ...
        START_DATE_AFTER_END_DATE: int = ...
        CANNOT_SET_DATE_TO_PAST: int = ...
        AFTER_MAXIMUM_ALLOWABLE_DATE: int = ...
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED: int = ...

class DayOfWeekEnum:
    class DayOfWeek(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MONDAY: int = ...
        TUESDAY: int = ...
        WEDNESDAY: int = ...
        THURSDAY: int = ...
        FRIDAY: int = ...
        SATURDAY: int = ...
        SUNDAY: int = ...

class DeviceEnum:
    class Device(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MOBILE: int = ...
        TABLET: int = ...
        DESKTOP: int = ...
        CONNECTED_TV: int = ...
        OTHER: int = ...

class DisplayAdFormatSettingEnum:
    class DisplayAdFormatSetting(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ALL_FORMATS: int = ...
        NON_NATIVE: int = ...
        NATIVE: int = ...

class DisplayUploadProductTypeEnum:
    class DisplayUploadProductType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        HTML5_UPLOAD_AD: int = ...
        DYNAMIC_HTML5_EDUCATION_AD: int = ...
        DYNAMIC_HTML5_FLIGHT_AD: int = ...
        DYNAMIC_HTML5_HOTEL_RENTAL_AD: int = ...
        DYNAMIC_HTML5_JOB_AD: int = ...
        DYNAMIC_HTML5_LOCAL_AD: int = ...
        DYNAMIC_HTML5_REAL_ESTATE_AD: int = ...
        DYNAMIC_HTML5_CUSTOM_AD: int = ...
        DYNAMIC_HTML5_TRAVEL_AD: int = ...
        DYNAMIC_HTML5_HOTEL_AD: int = ...

class DistanceBucketEnum:
    class DistanceBucket(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        WITHIN_700M: int = ...
        WITHIN_1KM: int = ...
        WITHIN_5KM: int = ...
        WITHIN_10KM: int = ...
        WITHIN_15KM: int = ...
        WITHIN_20KM: int = ...
        WITHIN_25KM: int = ...
        WITHIN_30KM: int = ...
        WITHIN_35KM: int = ...
        WITHIN_40KM: int = ...
        WITHIN_45KM: int = ...
        WITHIN_50KM: int = ...
        WITHIN_55KM: int = ...
        WITHIN_60KM: int = ...
        WITHIN_65KM: int = ...
        BEYOND_65KM: int = ...
        WITHIN_0_7MILES: int = ...
        WITHIN_1MILE: int = ...
        WITHIN_5MILES: int = ...
        WITHIN_10MILES: int = ...
        WITHIN_15MILES: int = ...
        WITHIN_20MILES: int = ...
        WITHIN_25MILES: int = ...
        WITHIN_30MILES: int = ...
        WITHIN_35MILES: int = ...
        WITHIN_40MILES: int = ...
        BEYOND_40MILES: int = ...

class DistinctErrorEnum:
    class DistinctError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DUPLICATE_ELEMENT: int = ...
        DUPLICATE_TYPE: int = ...

class DsaPageFeedCriterionFieldEnum:
    class DsaPageFeedCriterionField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PAGE_URL: int = ...
        LABEL: int = ...

class EducationPlaceholderFieldEnum:
    class EducationPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PROGRAM_ID: int = ...
        LOCATION_ID: int = ...
        PROGRAM_NAME: int = ...
        AREA_OF_STUDY: int = ...
        PROGRAM_DESCRIPTION: int = ...
        SCHOOL_NAME: int = ...
        ADDRESS: int = ...
        THUMBNAIL_IMAGE_URL: int = ...
        ALTERNATIVE_THUMBNAIL_IMAGE_URL: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        CONTEXTUAL_KEYWORDS: int = ...
        ANDROID_APP_LINK: int = ...
        SIMILAR_PROGRAM_IDS: int = ...
        IOS_APP_LINK: int = ...
        IOS_APP_STORE_ID: int = ...

class EnumErrorEnum:
    class EnumError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENUM_VALUE_NOT_PERMITTED: int = ...

class ExtensionFeedItemErrorEnum:
    class ExtensionFeedItemError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        VALUE_OUT_OF_RANGE: int = ...
        URL_LIST_TOO_LONG: int = ...
        CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING: int = ...
        CANNOT_SET_WITH_FINAL_URLS: int = ...
        CANNOT_SET_WITHOUT_FINAL_URLS: int = ...
        INVALID_PHONE_NUMBER: int = ...
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int = ...
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int = ...
        DISALLOWED_NUMBER_TYPE: int = ...
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT: int = ...
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int = ...
        INVALID_CALL_CONVERSION_ACTION: int = ...
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING: int = ...
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int = ...
        INVALID_APP_ID: int = ...
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int = ...
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET: int = ...
        REVIEW_EXTENSION_SOURCE_INELIGIBLE: int = ...
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT: int = ...
        INCONSISTENT_CURRENCY_CODES: int = ...
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS: int = ...
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION: int = ...
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS: int = ...
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS: int = ...
        UNSUPPORTED_VALUE: int = ...
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE: int = ...
        INVALID_DEVICE_PREFERENCE: int = ...
        INVALID_SCHEDULE_END: int = ...
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE: int = ...
        INVALID_SNIPPETS_HEADER: int = ...
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM: int = ...
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY: int = ...
        CONFLICTING_CALL_CONVERSION_SETTINGS: int = ...
        EXTENSION_TYPE_MISMATCH: int = ...
        EXTENSION_SUBTYPE_REQUIRED: int = ...
        EXTENSION_TYPE_UNSUPPORTED: int = ...
        CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS: int = ...
        CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES: int = ...
        INVALID_PRICE_FORMAT: int = ...
        PROMOTION_INVALID_TIME: int = ...
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int = ...
        CONCRETE_EXTENSION_TYPE_REQUIRED: int = ...
        SCHEDULE_END_NOT_AFTER_START: int = ...

class ExtensionSettingDeviceEnum:
    class ExtensionSettingDevice(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MOBILE: int = ...
        DESKTOP: int = ...

class ExtensionSettingErrorEnum:
    class ExtensionSettingError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EXTENSIONS_REQUIRED: int = ...
        FEED_TYPE_EXTENSION_TYPE_MISMATCH: int = ...
        INVALID_FEED_TYPE: int = ...
        INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING: int = ...
        CANNOT_CHANGE_FEED_ITEM_ON_CREATE: int = ...
        CANNOT_UPDATE_NEWLY_CREATED_EXTENSION: int = ...
        NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE: int = ...
        NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE: int = ...
        NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE: int = ...
        AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS: int = ...
        CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS: int = ...
        CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS: int = ...
        AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int = ...
        CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int = ...
        CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int = ...
        VALUE_OUT_OF_RANGE: int = ...
        CANNOT_SET_FIELD_WITH_FINAL_URLS: int = ...
        FINAL_URLS_NOT_SET: int = ...
        INVALID_PHONE_NUMBER: int = ...
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int = ...
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int = ...
        DISALLOWED_NUMBER_TYPE: int = ...
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT: int = ...
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int = ...
        INVALID_COUNTRY_CODE: int = ...
        INVALID_CALL_CONVERSION_TYPE_ID: int = ...
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING: int = ...
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        INVALID_APP_ID: int = ...
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int = ...
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET: int = ...
        REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE: int = ...
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT: int = ...
        MISSING_FIELD: int = ...
        INCONSISTENT_CURRENCY_CODES: int = ...
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS: int = ...
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION: int = ...
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS: int = ...
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS: int = ...
        UNSUPPORTED_VALUE: int = ...
        INVALID_DEVICE_PREFERENCE: int = ...
        INVALID_SCHEDULE_END: int = ...
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE: int = ...
        OVERLAPPING_SCHEDULES_NOT_ALLOWED: int = ...
        SCHEDULE_END_NOT_AFTER_START: int = ...
        TOO_MANY_SCHEDULES_PER_DAY: int = ...
        DUPLICATE_EXTENSION_FEED_ITEM_EDIT: int = ...
        INVALID_SNIPPETS_HEADER: int = ...
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY: int = ...
        CAMPAIGN_TARGETING_MISMATCH: int = ...
        CANNOT_OPERATE_ON_REMOVED_FEED: int = ...
        EXTENSION_TYPE_REQUIRED: int = ...
        INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION: int = ...
        START_DATE_AFTER_END_DATE: int = ...
        INVALID_PRICE_FORMAT: int = ...
        PROMOTION_INVALID_TIME: int = ...
        PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT: int = ...
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT: int = ...
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int = ...
        INVALID_LANGUAGE_CODE: int = ...
        UNSUPPORTED_LANGUAGE: int = ...
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int = ...
        EXTENSION_SETTING_UPDATE_IS_A_NOOP: int = ...

class ExtensionTypeEnum:
    class ExtensionType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NONE: int = ...
        APP: int = ...
        CALL: int = ...
        CALLOUT: int = ...
        MESSAGE: int = ...
        PRICE: int = ...
        PROMOTION: int = ...
        SITELINK: int = ...
        STRUCTURED_SNIPPET: int = ...
        LOCATION: int = ...
        AFFILIATE_LOCATION: int = ...
        HOTEL_CALLOUT: int = ...

class ExternalConversionSourceEnum:
    class ExternalConversionSource(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        WEBPAGE: int = ...
        ANALYTICS: int = ...
        UPLOAD: int = ...
        AD_CALL_METRICS: int = ...
        WEBSITE_CALL_METRICS: int = ...
        STORE_VISITS: int = ...
        ANDROID_IN_APP: int = ...
        IOS_IN_APP: int = ...
        IOS_FIRST_OPEN: int = ...
        APP_UNSPECIFIED: int = ...
        ANDROID_FIRST_OPEN: int = ...
        UPLOAD_CALLS: int = ...
        FIREBASE: int = ...
        CLICK_TO_CALL: int = ...
        SALESFORCE: int = ...
        STORE_SALES_CRM: int = ...
        STORE_SALES_PAYMENT_NETWORK: int = ...
        GOOGLE_PLAY: int = ...
        THIRD_PARTY_APP_ANALYTICS: int = ...
        GOOGLE_ATTRIBUTION: int = ...
        STORE_SALES_DIRECT: int = ...

class FeedAttributeOperation:
    class Operator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ADD: int = ...

class FeedAttributeReferenceErrorEnum:
    class FeedAttributeReferenceError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CANNOT_REFERENCE_REMOVED_FEED: int = ...
        INVALID_FEED_NAME: int = ...
        INVALID_FEED_ATTRIBUTE_NAME: int = ...

class FeedAttributeTypeEnum:
    class FeedAttributeType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INT64: int = ...
        DOUBLE: int = ...
        STRING: int = ...
        BOOLEAN: int = ...
        URL: int = ...
        DATE_TIME: int = ...
        INT64_LIST: int = ...
        DOUBLE_LIST: int = ...
        STRING_LIST: int = ...
        BOOLEAN_LIST: int = ...
        URL_LIST: int = ...
        DATE_TIME_LIST: int = ...
        PRICE: int = ...

class FeedErrorEnum:
    class FeedError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ATTRIBUTE_NAMES_NOT_UNIQUE: int = ...
        ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES: int = ...
        CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED: int = ...
        CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED: int = ...
        CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED: int = ...
        CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE: int = ...
        FEED_REMOVED: int = ...
        INVALID_ORIGIN_VALUE: int = ...
        FEED_ORIGIN_IS_NOT_USER: int = ...
        INVALID_AUTH_TOKEN_FOR_EMAIL: int = ...
        INVALID_EMAIL: int = ...
        DUPLICATE_FEED_NAME: int = ...
        INVALID_FEED_NAME: int = ...
        MISSING_OAUTH_INFO: int = ...
        NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY: int = ...
        TOO_MANY_ATTRIBUTES: int = ...
        INVALID_BUSINESS_ACCOUNT: int = ...
        BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT: int = ...
        INVALID_AFFILIATE_CHAIN_ID: int = ...
        DUPLICATE_SYSTEM_FEED: int = ...
        GMB_ACCESS_ERROR: int = ...
        CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS: int = ...

class FeedItemErrorEnum:
    class FeedItemError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING: int = ...
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM: int = ...
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE: int = ...
        KEY_ATTRIBUTES_NOT_FOUND: int = ...
        INVALID_URL: int = ...
        MISSING_KEY_ATTRIBUTES: int = ...
        KEY_ATTRIBUTES_NOT_UNIQUE: int = ...
        CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE: int = ...
        SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE: int = ...

class FeedItemQualityApprovalStatusEnum:
    class FeedItemQualityApprovalStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        APPROVED: int = ...
        DISAPPROVED: int = ...

class FeedItemQualityDisapprovalReasonEnum:
    class FeedItemQualityDisapprovalReason(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PRICE_TABLE_REPETITIVE_HEADERS: int = ...
        PRICE_TABLE_REPETITIVE_DESCRIPTION: int = ...
        PRICE_TABLE_INCONSISTENT_ROWS: int = ...
        PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS: int = ...
        PRICE_UNSUPPORTED_LANGUAGE: int = ...
        PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH: int = ...
        PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT: int = ...
        PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT: int = ...
        PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT: int = ...
        PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE: int = ...
        PRICE_TABLE_ROW_UNRATEABLE: int = ...
        PRICE_TABLE_ROW_PRICE_INVALID: int = ...
        PRICE_TABLE_ROW_URL_INVALID: int = ...
        PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE: int = ...
        STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED: int = ...
        STRUCTURED_SNIPPETS_REPEATED_VALUES: int = ...
        STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES: int = ...
        STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT: int = ...

class FeedItemStatusEnum:
    class FeedItemStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class FeedItemTargetDeviceEnum:
    class FeedItemTargetDevice(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MOBILE: int = ...

class FeedItemTargetErrorEnum:
    class FeedItemTargetError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MUST_SET_TARGET_ONEOF_ON_CREATE: int = ...
        FEED_ITEM_TARGET_ALREADY_EXISTS: int = ...
        FEED_ITEM_SCHEDULES_CANNOT_OVERLAP: int = ...
        TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE: int = ...
        TOO_MANY_SCHEDULES_PER_DAY: int = ...
        CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS: int = ...
        DUPLICATE_AD_SCHEDULE: int = ...
        DUPLICATE_KEYWORD: int = ...

class FeedItemTargetStatusEnum:
    class FeedItemTargetStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class FeedItemTargetTypeEnum:
    class FeedItemTargetType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CAMPAIGN: int = ...
        AD_GROUP: int = ...
        CRITERION: int = ...

class FeedItemValidationErrorEnum:
    class FeedItemValidationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        STRING_TOO_SHORT: int = ...
        STRING_TOO_LONG: int = ...
        VALUE_NOT_SPECIFIED: int = ...
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT: int = ...
        INVALID_PHONE_NUMBER: int = ...
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int = ...
        DISALLOWED_NUMBER_TYPE: int = ...
        VALUE_OUT_OF_RANGE: int = ...
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING: int = ...
        INVALID_COUNTRY_CODE: int = ...
        INVALID_APP_ID: int = ...
        MISSING_ATTRIBUTES_FOR_FIELDS: int = ...
        INVALID_TYPE_ID: int = ...
        INVALID_EMAIL_ADDRESS: int = ...
        INVALID_HTTPS_URL: int = ...
        MISSING_DELIVERY_ADDRESS: int = ...
        START_DATE_AFTER_END_DATE: int = ...
        MISSING_FEED_ITEM_START_TIME: int = ...
        MISSING_FEED_ITEM_END_TIME: int = ...
        MISSING_FEED_ITEM_ID: int = ...
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int = ...
        INVALID_REVIEW_EXTENSION_SNIPPET: int = ...
        INVALID_NUMBER_FORMAT: int = ...
        INVALID_DATE_FORMAT: int = ...
        INVALID_PRICE_FORMAT: int = ...
        UNKNOWN_PLACEHOLDER_FIELD: int = ...
        MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE: int = ...
        REVIEW_EXTENSION_SOURCE_INELIGIBLE: int = ...
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET: int = ...
        DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int = ...
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int = ...
        INVALID_FORM_ENCODED_PARAMS: int = ...
        INVALID_URL_PARAMETER_NAME: int = ...
        NO_GEOCODING_RESULT: int = ...
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT: int = ...
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int = ...
        INVALID_PLACEHOLDER_FIELD_ID: int = ...
        INVALID_URL_TAG: int = ...
        LIST_TOO_LONG: int = ...
        INVALID_ATTRIBUTES_COMBINATION: int = ...
        DUPLICATE_VALUES: int = ...
        INVALID_CALL_CONVERSION_ACTION_ID: int = ...
        CANNOT_SET_WITHOUT_FINAL_URLS: int = ...
        APP_ID_DOESNT_EXIST_IN_APP_STORE: int = ...
        INVALID_FINAL_URL: int = ...
        INVALID_TRACKING_URL: int = ...
        INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL: int = ...
        LIST_TOO_SHORT: int = ...
        INVALID_USER_ACTION: int = ...
        INVALID_TYPE_NAME: int = ...
        INVALID_EVENT_CHANGE_STATUS: int = ...
        INVALID_SNIPPETS_HEADER: int = ...
        INVALID_ANDROID_APP_LINK: int = ...
        NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int = ...
        RESERVED_KEYWORD_OTHER: int = ...
        DUPLICATE_OPTION_LABELS: int = ...
        DUPLICATE_OPTION_PREFILLS: int = ...
        UNEQUAL_LIST_LENGTHS: int = ...
        INCONSISTENT_CURRENCY_CODES: int = ...
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS: int = ...
        ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION: int = ...
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS: int = ...
        UNSUPPORTED_VALUE: int = ...
        INVALID_FINAL_MOBILE_URL: int = ...
        INVALID_KEYWORDLESS_AD_RULE_LABEL: int = ...
        VALUE_TRACK_PARAMETER_NOT_SUPPORTED: int = ...
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE: int = ...
        INVALID_IOS_APP_LINK: int = ...
        MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID: int = ...
        PROMOTION_INVALID_TIME: int = ...
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF: int = ...
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT: int = ...
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int = ...
        AD_CUSTOMIZERS_NOT_ALLOWED: int = ...
        INVALID_LANGUAGE_CODE: int = ...
        UNSUPPORTED_LANGUAGE: int = ...
        IF_FUNCTION_NOT_ALLOWED: int = ...
        INVALID_FINAL_URL_SUFFIX: int = ...
        INVALID_TAG_IN_FINAL_URL_SUFFIX: int = ...
        INVALID_FINAL_URL_SUFFIX_FORMAT: int = ...
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int = ...
        ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED: int = ...
        NO_DELIVERY_OPTION_IS_SET: int = ...
        INVALID_CONVERSION_REPORTING_STATE: int = ...
        IMAGE_SIZE_WRONG: int = ...
        EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY: int = ...
        AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY: int = ...
        INVALID_LATITUDE_VALUE: int = ...
        INVALID_LONGITUDE_VALUE: int = ...
        TOO_MANY_LABELS: int = ...
        INVALID_IMAGE_URL: int = ...
        MISSING_LATITUDE_VALUE: int = ...
        MISSING_LONGITUDE_VALUE: int = ...
        ADDRESS_NOT_FOUND: int = ...
        ADDRESS_NOT_TARGETABLE: int = ...

class FeedItemValidationStatusEnum:
    class FeedItemValidationStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PENDING: int = ...
        INVALID: int = ...
        VALID: int = ...

class FeedLinkStatusEnum:
    class FeedLinkStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class FeedMappingCriterionTypeEnum:
    class FeedMappingCriterionType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LOCATION_EXTENSION_TARGETING: int = ...
        DSA_PAGE_FEED: int = ...

class FeedMappingErrorEnum:
    class FeedMappingError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_PLACEHOLDER_FIELD: int = ...
        INVALID_CRITERION_FIELD: int = ...
        INVALID_PLACEHOLDER_TYPE: int = ...
        INVALID_CRITERION_TYPE: int = ...
        NO_ATTRIBUTE_FIELD_MAPPINGS: int = ...
        FEED_ATTRIBUTE_TYPE_MISMATCH: int = ...
        CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED: int = ...
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE: int = ...
        MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE: int = ...
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD: int = ...
        MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD: int = ...
        UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS: int = ...
        LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS: int = ...
        CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED: int = ...
        INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED: int = ...
        INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE: int = ...
        ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD: int = ...

class FeedMappingStatusEnum:
    class FeedMappingStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class FeedOriginEnum:
    class FeedOrigin(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        USER: int = ...
        GOOGLE: int = ...

class FeedStatusEnum:
    class FeedStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class FieldErrorEnum:
    class FieldError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        REQUIRED: int = ...
        IMMUTABLE_FIELD: int = ...
        INVALID_VALUE: int = ...
        VALUE_MUST_BE_UNSET: int = ...
        REQUIRED_NONEMPTY_LIST: int = ...
        FIELD_CANNOT_BE_CLEARED: int = ...
        BLACKLISTED_VALUE: int = ...

class FieldMaskErrorEnum:
    class FieldMaskError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FIELD_MASK_MISSING: int = ...
        FIELD_MASK_NOT_ALLOWED: int = ...
        FIELD_NOT_FOUND: int = ...
        FIELD_HAS_SUBFIELDS: int = ...

class FlightPlaceholderFieldEnum:
    class FlightPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DESTINATION_ID: int = ...
        ORIGIN_ID: int = ...
        FLIGHT_DESCRIPTION: int = ...
        ORIGIN_NAME: int = ...
        DESTINATION_NAME: int = ...
        FLIGHT_PRICE: int = ...
        FORMATTED_PRICE: int = ...
        FLIGHT_SALE_PRICE: int = ...
        FORMATTED_SALE_PRICE: int = ...
        IMAGE_URL: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        ANDROID_APP_LINK: int = ...
        SIMILAR_DESTINATION_IDS: int = ...
        IOS_APP_LINK: int = ...
        IOS_APP_STORE_ID: int = ...

class FrequencyCapEventTypeEnum:
    class FrequencyCapEventType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        IMPRESSION: int = ...
        VIDEO_VIEW: int = ...

class FrequencyCapLevelEnum:
    class FrequencyCapLevel(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_GROUP_AD: int = ...
        AD_GROUP: int = ...
        CAMPAIGN: int = ...

class FrequencyCapTimeUnitEnum:
    class FrequencyCapTimeUnit(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DAY: int = ...
        WEEK: int = ...
        MONTH: int = ...

class FunctionErrorEnum:
    class FunctionError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_FUNCTION_FORMAT: int = ...
        DATA_TYPE_MISMATCH: int = ...
        INVALID_CONJUNCTION_OPERANDS: int = ...
        INVALID_NUMBER_OF_OPERANDS: int = ...
        INVALID_OPERAND_TYPE: int = ...
        INVALID_OPERATOR: int = ...
        INVALID_REQUEST_CONTEXT_TYPE: int = ...
        INVALID_FUNCTION_FOR_CALL_PLACEHOLDER: int = ...
        INVALID_FUNCTION_FOR_PLACEHOLDER: int = ...
        INVALID_OPERAND: int = ...
        MISSING_CONSTANT_OPERAND_VALUE: int = ...
        INVALID_CONSTANT_OPERAND_VALUE: int = ...
        INVALID_NESTING: int = ...
        MULTIPLE_FEED_IDS_NOT_SUPPORTED: int = ...
        INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA: int = ...
        INVALID_ATTRIBUTE_NAME: int = ...

class FunctionParsingErrorEnum:
    class FunctionParsingError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NO_MORE_INPUT: int = ...
        EXPECTED_CHARACTER: int = ...
        UNEXPECTED_SEPARATOR: int = ...
        UNMATCHED_LEFT_BRACKET: int = ...
        UNMATCHED_RIGHT_BRACKET: int = ...
        TOO_MANY_NESTED_FUNCTIONS: int = ...
        MISSING_RIGHT_HAND_OPERAND: int = ...
        INVALID_OPERATOR_NAME: int = ...
        FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER: int = ...
        NO_OPERANDS: int = ...
        TOO_MANY_OPERANDS: int = ...

class GenderTypeEnum:
    class GenderType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MALE: int = ...
        FEMALE: int = ...
        UNDETERMINED: int = ...

class GeoTargetConstantStatusEnum:
    class GeoTargetConstantStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVAL_PLANNED: int = ...

class GeoTargetConstantSuggestionErrorEnum:
    class GeoTargetConstantSuggestionError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LOCATION_NAME_SIZE_LIMIT: int = ...
        LOCATION_NAME_LIMIT: int = ...
        INVALID_COUNTRY_CODE: int = ...
        REQUEST_PARAMETERS_UNSET: int = ...

class GeoTargetingRestrictionEnum:
    class GeoTargetingRestriction(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LOCATION_OF_PRESENCE: int = ...

class GeoTargetingTypeEnum:
    class GeoTargetingType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AREA_OF_INTEREST: int = ...
        LOCATION_OF_PRESENCE: int = ...

class GoogleAdsFieldCategoryEnum:
    class GoogleAdsFieldCategory(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        RESOURCE: int = ...
        ATTRIBUTE: int = ...
        SEGMENT: int = ...
        METRIC: int = ...

class GoogleAdsFieldDataTypeEnum:
    class GoogleAdsFieldDataType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BOOLEAN: int = ...
        DATE: int = ...
        DOUBLE: int = ...
        ENUM: int = ...
        FLOAT: int = ...
        INT32: int = ...
        INT64: int = ...
        MESSAGE: int = ...
        RESOURCE_NAME: int = ...
        STRING: int = ...
        UINT64: int = ...

class HeaderErrorEnum:
    class HeaderError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_LOGIN_CUSTOMER_ID: int = ...

class HotelDateSelectionTypeEnum:
    class HotelDateSelectionType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DEFAULT_SELECTION: int = ...
        USER_SELECTED: int = ...

class HotelPlaceholderFieldEnum:
    class HotelPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PROPERTY_ID: int = ...
        PROPERTY_NAME: int = ...
        DESTINATION_NAME: int = ...
        DESCRIPTION: int = ...
        ADDRESS: int = ...
        PRICE: int = ...
        FORMATTED_PRICE: int = ...
        SALE_PRICE: int = ...
        FORMATTED_SALE_PRICE: int = ...
        IMAGE_URL: int = ...
        CATEGORY: int = ...
        STAR_RATING: int = ...
        CONTEXTUAL_KEYWORDS: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        ANDROID_APP_LINK: int = ...
        SIMILAR_PROPERTY_IDS: int = ...
        IOS_APP_LINK: int = ...
        IOS_APP_STORE_ID: int = ...

class HotelPriceBucketEnum:
    class HotelPriceBucket(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LOWEST_TIED: int = ...
        NOT_LOWEST: int = ...

class HotelRateTypeEnum:
    class HotelRateType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        UNAVAILABLE: int = ...
        PUBLIC_RATE: int = ...
        QUALIFIED_RATE: int = ...
        PRIVATE_RATE: int = ...

class IdErrorEnum:
    class IdError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NOT_FOUND: int = ...

class ImageErrorEnum:
    class ImageError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_IMAGE: int = ...
        STORAGE_ERROR: int = ...
        BAD_REQUEST: int = ...
        UNEXPECTED_SIZE: int = ...
        ANIMATED_NOT_ALLOWED: int = ...
        ANIMATION_TOO_LONG: int = ...
        SERVER_ERROR: int = ...
        CMYK_JPEG_NOT_ALLOWED: int = ...
        FLASH_NOT_ALLOWED: int = ...
        FLASH_WITHOUT_CLICKTAG: int = ...
        FLASH_ERROR_AFTER_FIXING_CLICK_TAG: int = ...
        ANIMATED_VISUAL_EFFECT: int = ...
        FLASH_ERROR: int = ...
        LAYOUT_PROBLEM: int = ...
        PROBLEM_READING_IMAGE_FILE: int = ...
        ERROR_STORING_IMAGE: int = ...
        ASPECT_RATIO_NOT_ALLOWED: int = ...
        FLASH_HAS_NETWORK_OBJECTS: int = ...
        FLASH_HAS_NETWORK_METHODS: int = ...
        FLASH_HAS_URL: int = ...
        FLASH_HAS_MOUSE_TRACKING: int = ...
        FLASH_HAS_RANDOM_NUM: int = ...
        FLASH_SELF_TARGETS: int = ...
        FLASH_BAD_GETURL_TARGET: int = ...
        FLASH_VERSION_NOT_SUPPORTED: int = ...
        FLASH_WITHOUT_HARD_CODED_CLICK_URL: int = ...
        INVALID_FLASH_FILE: int = ...
        FAILED_TO_FIX_CLICK_TAG_IN_FLASH: int = ...
        FLASH_ACCESSES_NETWORK_RESOURCES: int = ...
        FLASH_EXTERNAL_JS_CALL: int = ...
        FLASH_EXTERNAL_FS_CALL: int = ...
        FILE_TOO_LARGE: int = ...
        IMAGE_DATA_TOO_LARGE: int = ...
        IMAGE_PROCESSING_ERROR: int = ...
        IMAGE_TOO_SMALL: int = ...
        INVALID_INPUT: int = ...
        PROBLEM_READING_FILE: int = ...
        IMAGE_CONSTRAINTS_VIOLATED: int = ...

class IncomeRangeTypeEnum:
    class IncomeRangeType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INCOME_RANGE_0_50: int = ...
        INCOME_RANGE_50_60: int = ...
        INCOME_RANGE_60_70: int = ...
        INCOME_RANGE_70_80: int = ...
        INCOME_RANGE_80_90: int = ...
        INCOME_RANGE_90_UP: int = ...
        INCOME_RANGE_UNDETERMINED: int = ...

class InteractionEventTypeEnum:
    class InteractionEventType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CLICK: int = ...
        ENGAGEMENT: int = ...
        VIDEO_VIEW: int = ...
        NONE: int = ...

class InteractionTypeEnum:
    class InteractionType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CALLS: int = ...

class InternalErrorEnum:
    class InternalError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INTERNAL_ERROR: int = ...
        ERROR_CODE_NOT_PUBLISHED: int = ...
        TRANSIENT_ERROR: int = ...
        DEADLINE_EXCEEDED: int = ...

class InvoiceErrorEnum:
    class InvoiceError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        YEAR_MONTH_TOO_OLD: int = ...
        NOT_INVOICED_CUSTOMER: int = ...

class InvoiceTypeEnum:
    class InvoiceType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CREDIT_MEMO: int = ...
        INVOICE: int = ...

class JobPlaceholderFieldEnum:
    class JobPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        JOB_ID: int = ...
        LOCATION_ID: int = ...
        TITLE: int = ...
        SUBTITLE: int = ...
        DESCRIPTION: int = ...
        IMAGE_URL: int = ...
        CATEGORY: int = ...
        CONTEXTUAL_KEYWORDS: int = ...
        ADDRESS: int = ...
        SALARY: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        ANDROID_APP_LINK: int = ...
        SIMILAR_JOB_IDS: int = ...
        IOS_APP_LINK: int = ...
        IOS_APP_STORE_ID: int = ...

class KeywordMatchTypeEnum:
    class KeywordMatchType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EXACT: int = ...
        PHRASE: int = ...
        BROAD: int = ...

class KeywordPlanAdGroupErrorEnum:
    class KeywordPlanAdGroupError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_NAME: int = ...
        DUPLICATE_NAME: int = ...

class KeywordPlanCampaignErrorEnum:
    class KeywordPlanCampaignError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_NAME: int = ...
        INVALID_LANGUAGES: int = ...
        INVALID_GEOS: int = ...
        DUPLICATE_NAME: int = ...
        MAX_GEOS_EXCEEDED: int = ...

class KeywordPlanCompetitionLevelEnum:
    class KeywordPlanCompetitionLevel(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LOW: int = ...
        MEDIUM: int = ...
        HIGH: int = ...

class KeywordPlanErrorEnum:
    class KeywordPlanError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BID_MULTIPLIER_OUT_OF_RANGE: int = ...
        BID_TOO_HIGH: int = ...
        BID_TOO_LOW: int = ...
        BID_TOO_MANY_FRACTIONAL_DIGITS: int = ...
        DAILY_BUDGET_TOO_LOW: int = ...
        DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS: int = ...
        INVALID_VALUE: int = ...
        KEYWORD_PLAN_HAS_NO_KEYWORDS: int = ...
        KEYWORD_PLAN_NOT_ENABLED: int = ...
        KEYWORD_PLAN_NOT_FOUND: int = ...
        MISSING_BID: int = ...
        MISSING_FORECAST_PERIOD: int = ...
        INVALID_FORECAST_DATE_RANGE: int = ...
        INVALID_NAME: int = ...

class KeywordPlanForecastIntervalEnum:
    class KeywordPlanForecastInterval(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NEXT_WEEK: int = ...
        NEXT_MONTH: int = ...
        NEXT_QUARTER: int = ...

class KeywordPlanIdeaErrorEnum:
    class KeywordPlanIdeaError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        URL_CRAWL_ERROR: int = ...
        INVALID_VALUE: int = ...

class KeywordPlanKeywordErrorEnum:
    class KeywordPlanKeywordError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_KEYWORD_MATCH_TYPE: int = ...
        DUPLICATE_KEYWORD: int = ...
        KEYWORD_TEXT_TOO_LONG: int = ...
        KEYWORD_HAS_INVALID_CHARS: int = ...
        KEYWORD_HAS_TOO_MANY_WORDS: int = ...
        INVALID_KEYWORD_TEXT: int = ...

class KeywordPlanNegativeKeywordErrorEnum:
    class KeywordPlanNegativeKeywordError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...

class KeywordPlanNetworkEnum:
    class KeywordPlanNetwork(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        GOOGLE_SEARCH: int = ...
        GOOGLE_SEARCH_AND_PARTNERS: int = ...

class LabelErrorEnum:
    class LabelError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CANNOT_APPLY_INACTIVE_LABEL: int = ...
        CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION: int = ...
        CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION: int = ...
        EXCEEDED_LABEL_LIMIT_PER_TYPE: int = ...
        INVALID_RESOURCE_FOR_MANAGER_LABEL: int = ...
        DUPLICATE_NAME: int = ...
        INVALID_LABEL_NAME: int = ...
        CANNOT_ATTACH_LABEL_TO_DRAFT: int = ...
        CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER: int = ...

class LabelStatusEnum:
    class LabelStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class LanguageCodeErrorEnum:
    class LanguageCodeError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LANGUAGE_CODE_NOT_FOUND: int = ...
        INVALID_LANGUAGE_CODE: int = ...

class LegacyAppInstallAdAppStoreEnum:
    class LegacyAppInstallAdAppStore(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        APPLE_APP_STORE: int = ...
        GOOGLE_PLAY: int = ...
        WINDOWS_STORE: int = ...
        WINDOWS_PHONE_STORE: int = ...
        CN_APP_STORE: int = ...

class ListOperationErrorEnum:
    class ListOperationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        REQUIRED_FIELD_MISSING: int = ...
        DUPLICATE_VALUES: int = ...

class ListingGroupTypeEnum:
    class ListingGroupType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SUBDIVISION: int = ...
        UNIT: int = ...

class LocalPlaceholderFieldEnum:
    class LocalPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DEAL_ID: int = ...
        DEAL_NAME: int = ...
        SUBTITLE: int = ...
        DESCRIPTION: int = ...
        PRICE: int = ...
        FORMATTED_PRICE: int = ...
        SALE_PRICE: int = ...
        FORMATTED_SALE_PRICE: int = ...
        IMAGE_URL: int = ...
        ADDRESS: int = ...
        CATEGORY: int = ...
        CONTEXTUAL_KEYWORDS: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        ANDROID_APP_LINK: int = ...
        SIMILAR_DEAL_IDS: int = ...
        IOS_APP_LINK: int = ...
        IOS_APP_STORE_ID: int = ...

class LocationExtensionTargetingCriterionFieldEnum:
    class LocationExtensionTargetingCriterionField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ADDRESS_LINE_1: int = ...
        ADDRESS_LINE_2: int = ...
        CITY: int = ...
        PROVINCE: int = ...
        POSTAL_CODE: int = ...
        COUNTRY_CODE: int = ...

class LocationGroupRadiusUnitsEnum:
    class LocationGroupRadiusUnits(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        METERS: int = ...
        MILES: int = ...

class LocationPlaceholderFieldEnum:
    class LocationPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BUSINESS_NAME: int = ...
        ADDRESS_LINE_1: int = ...
        ADDRESS_LINE_2: int = ...
        CITY: int = ...
        PROVINCE: int = ...
        POSTAL_CODE: int = ...
        COUNTRY_CODE: int = ...
        PHONE_NUMBER: int = ...

class ManagerLinkErrorEnum:
    class ManagerLinkError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING: int = ...
        TOO_MANY_MANAGERS: int = ...
        TOO_MANY_INVITES: int = ...
        ALREADY_INVITED_BY_THIS_MANAGER: int = ...
        ALREADY_MANAGED_BY_THIS_MANAGER: int = ...
        ALREADY_MANAGED_IN_HIERARCHY: int = ...
        DUPLICATE_CHILD_FOUND: int = ...
        CLIENT_HAS_NO_ADMIN_USER: int = ...
        MAX_DEPTH_EXCEEDED: int = ...
        CYCLE_NOT_ALLOWED: int = ...
        TOO_MANY_ACCOUNTS: int = ...
        TOO_MANY_ACCOUNTS_AT_MANAGER: int = ...
        NON_OWNER_USER_CANNOT_MODIFY_LINK: int = ...
        SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS: int = ...
        CLIENT_OUTSIDE_TREE: int = ...

class ManagerLinkStatusEnum:
    class ManagerLinkStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ACTIVE: int = ...
        INACTIVE: int = ...
        PENDING: int = ...
        REFUSED: int = ...
        CANCELED: int = ...

class MatchingFunctionContextTypeEnum:
    class MatchingFunctionContextType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FEED_ITEM_ID: int = ...
        DEVICE_NAME: int = ...

class MatchingFunctionOperatorEnum:
    class MatchingFunctionOperator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        IN: int = ...
        IDENTITY: int = ...
        EQUALS: int = ...
        AND: int = ...
        CONTAINS_ANY: int = ...

class MediaBundleErrorEnum:
    class MediaBundleError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BAD_REQUEST: int = ...
        DOUBLECLICK_BUNDLE_NOT_ALLOWED: int = ...
        EXTERNAL_URL_NOT_ALLOWED: int = ...
        FILE_TOO_LARGE: int = ...
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED: int = ...
        INVALID_INPUT: int = ...
        INVALID_MEDIA_BUNDLE: int = ...
        INVALID_MEDIA_BUNDLE_ENTRY: int = ...
        INVALID_MIME_TYPE: int = ...
        INVALID_PATH: int = ...
        INVALID_URL_REFERENCE: int = ...
        MEDIA_DATA_TOO_LARGE: int = ...
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY: int = ...
        SERVER_ERROR: int = ...
        STORAGE_ERROR: int = ...
        SWIFFY_BUNDLE_NOT_ALLOWED: int = ...
        TOO_MANY_FILES: int = ...
        UNEXPECTED_SIZE: int = ...
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT: int = ...
        UNSUPPORTED_HTML5_FEATURE: int = ...
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT: int = ...
        CUSTOM_EXIT_NOT_ALLOWED: int = ...

class MediaFileErrorEnum:
    class MediaFileError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CANNOT_CREATE_STANDARD_ICON: int = ...
        CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES: int = ...
        CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA: int = ...
        DUPLICATE_MEDIA: int = ...
        EMPTY_FIELD: int = ...
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS: int = ...
        FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE: int = ...
        INVALID_MEDIA_FILE_ID: int = ...
        INVALID_MEDIA_SUB_TYPE: int = ...
        INVALID_MEDIA_FILE_TYPE: int = ...
        INVALID_MIME_TYPE: int = ...
        INVALID_REFERENCE_ID: int = ...
        INVALID_YOU_TUBE_ID: int = ...
        MEDIA_FILE_FAILED_TRANSCODING: int = ...
        MEDIA_NOT_TRANSCODED: int = ...
        MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE: int = ...
        NO_FIELDS_SPECIFIED: int = ...
        NULL_REFERENCE_ID_AND_MEDIA_ID: int = ...
        TOO_LONG: int = ...
        UNSUPPORTED_TYPE: int = ...
        YOU_TUBE_SERVICE_UNAVAILABLE: int = ...
        YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION: int = ...
        YOU_TUBE_VIDEO_NOT_FOUND: int = ...

class MediaTypeEnum:
    class MediaType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        IMAGE: int = ...
        ICON: int = ...
        MEDIA_BUNDLE: int = ...
        AUDIO: int = ...
        VIDEO: int = ...
        DYNAMIC_IMAGE: int = ...

class MediaUploadErrorEnum:
    class MediaUploadError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FILE_TOO_BIG: int = ...
        UNPARSEABLE_IMAGE: int = ...
        ANIMATED_IMAGE_NOT_ALLOWED: int = ...
        FORMAT_NOT_ALLOWED: int = ...
        EXTERNAL_URL_NOT_ALLOWED: int = ...
        INVALID_URL_REFERENCE: int = ...
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY: int = ...

class MerchantCenterLinkStatusEnum:
    class MerchantCenterLinkStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        PENDING: int = ...

class MessagePlaceholderFieldEnum:
    class MessagePlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BUSINESS_NAME: int = ...
        COUNTRY_CODE: int = ...
        PHONE_NUMBER: int = ...
        MESSAGE_EXTENSION_TEXT: int = ...
        MESSAGE_TEXT: int = ...

class MimeTypeEnum:
    class MimeType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        IMAGE_JPEG: int = ...
        IMAGE_GIF: int = ...
        IMAGE_PNG: int = ...
        FLASH: int = ...
        TEXT_HTML: int = ...
        PDF: int = ...
        MSWORD: int = ...
        MSEXCEL: int = ...
        RTF: int = ...
        AUDIO_WAV: int = ...
        AUDIO_MP3: int = ...
        HTML5_AD_ZIP: int = ...

class MinuteOfHourEnum:
    class MinuteOfHour(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ZERO: int = ...
        FIFTEEN: int = ...
        THIRTY: int = ...
        FORTY_FIVE: int = ...

class MobileDeviceTypeEnum:
    class MobileDeviceType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MOBILE: int = ...
        TABLET: int = ...

class MonthOfYearEnum:
    class MonthOfYear(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        JANUARY: int = ...
        FEBRUARY: int = ...
        MARCH: int = ...
        APRIL: int = ...
        MAY: int = ...
        JUNE: int = ...
        JULY: int = ...
        AUGUST: int = ...
        SEPTEMBER: int = ...
        OCTOBER: int = ...
        NOVEMBER: int = ...
        DECEMBER: int = ...

class MultiplierErrorEnum:
    class MultiplierError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MULTIPLIER_TOO_HIGH: int = ...
        MULTIPLIER_TOO_LOW: int = ...
        TOO_MANY_FRACTIONAL_DIGITS: int = ...
        MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY: int = ...
        MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING: int = ...
        NO_MULTIPLIER_SPECIFIED: int = ...
        MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET: int = ...
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET: int = ...
        MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET: int = ...
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID: int = ...
        BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER: int = ...
        MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH: int = ...

class MutateErrorEnum:
    class MutateError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        RESOURCE_NOT_FOUND: int = ...
        ID_EXISTS_IN_MULTIPLE_MUTATES: int = ...
        INCONSISTENT_FIELD_VALUES: int = ...
        MUTATE_NOT_ALLOWED: int = ...
        RESOURCE_NOT_IN_GOOGLE_ADS: int = ...
        RESOURCE_ALREADY_EXISTS: int = ...

class MutateJobErrorEnum:
    class MutateJobError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING: int = ...
        EMPTY_OPERATIONS: int = ...
        INVALID_SEQUENCE_TOKEN: int = ...
        RESULTS_NOT_READY: int = ...
        INVALID_PAGE_SIZE: int = ...

class MutateJobStatusEnum:
    class MutateJobStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PENDING: int = ...
        RUNNING: int = ...
        DONE: int = ...

class NegativeGeoTargetTypeEnum:
    class NegativeGeoTargetType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PRESENCE_OR_INTEREST: int = ...
        PRESENCE: int = ...

class NewResourceCreationErrorEnum:
    class NewResourceCreationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CANNOT_SET_ID_FOR_CREATE: int = ...
        DUPLICATE_TEMP_IDS: int = ...
        TEMP_ID_RESOURCE_HAD_ERRORS: int = ...

class NotEmptyErrorEnum:
    class NotEmptyError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EMPTY_LIST: int = ...

class NotWhitelistedErrorEnum:
    class NotWhitelistedError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CUSTOMER_NOT_WHITELISTED_FOR_THIS_FEATURE: int = ...

class NullErrorEnum:
    class NullError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NULL_CONTENT: int = ...

class OfflineUserDataJobFailureReasonEnum:
    class OfflineUserDataJobFailureReason(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INSUFFICIENT_MATCHED_TRANSACTIONS: int = ...
        INSUFFICIENT_TRANSACTIONS: int = ...

class OfflineUserDataJobStatusEnum:
    class OfflineUserDataJobStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PENDING: int = ...
        RUNNING: int = ...
        SUCCESS: int = ...
        FAILED: int = ...

class OfflineUserDataJobTypeEnum:
    class OfflineUserDataJobType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        STORE_SALES_UPLOAD_FIRST_PARTY: int = ...
        STORE_SALES_UPLOAD_THIRD_PARTY: int = ...
        CUSTOMER_MATCH_USER_LIST: int = ...

class OperatingSystemVersionOperatorTypeEnum:
    class OperatingSystemVersionOperatorType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EQUALS_TO: int = ...
        GREATER_THAN_EQUALS_TO: int = ...

class OperationAccessDeniedErrorEnum:
    class OperationAccessDeniedError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ACTION_NOT_PERMITTED: int = ...
        CREATE_OPERATION_NOT_PERMITTED: int = ...
        REMOVE_OPERATION_NOT_PERMITTED: int = ...
        UPDATE_OPERATION_NOT_PERMITTED: int = ...
        MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT: int = ...
        OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE: int = ...
        CREATE_AS_REMOVED_NOT_PERMITTED: int = ...
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE: int = ...
        OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE: int = ...
        MUTATE_NOT_PERMITTED_FOR_CUSTOMER: int = ...

class OperatorErrorEnum:
    class OperatorError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        OPERATOR_NOT_SUPPORTED: int = ...

class ParentalStatusTypeEnum:
    class ParentalStatusType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PARENT: int = ...
        NOT_A_PARENT: int = ...
        UNDETERMINED: int = ...

class PartialFailureErrorEnum:
    class PartialFailureError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PARTIAL_FAILURE_MODE_REQUIRED: int = ...

class PaymentModeEnum:
    class PaymentMode(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CLICKS: int = ...
        CONVERSION_VALUE: int = ...
        CONVERSIONS: int = ...
        GUEST_STAY: int = ...

class PaymentsAccountErrorEnum:
    class PaymentsAccountError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NOT_SUPPORTED_FOR_MANAGER_CUSTOMER: int = ...

class PlaceholderTypeEnum:
    class PlaceholderType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SITELINK: int = ...
        CALL: int = ...
        APP: int = ...
        LOCATION: int = ...
        AFFILIATE_LOCATION: int = ...
        CALLOUT: int = ...
        STRUCTURED_SNIPPET: int = ...
        MESSAGE: int = ...
        PRICE: int = ...
        PROMOTION: int = ...
        AD_CUSTOMIZER: int = ...
        DYNAMIC_EDUCATION: int = ...
        DYNAMIC_FLIGHT: int = ...
        DYNAMIC_CUSTOM: int = ...
        DYNAMIC_HOTEL: int = ...
        DYNAMIC_REAL_ESTATE: int = ...
        DYNAMIC_TRAVEL: int = ...
        DYNAMIC_LOCAL: int = ...
        DYNAMIC_JOB: int = ...

class PlacementTypeEnum:
    class PlacementType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        WEBSITE: int = ...
        MOBILE_APP_CATEGORY: int = ...
        MOBILE_APPLICATION: int = ...
        YOUTUBE_VIDEO: int = ...
        YOUTUBE_CHANNEL: int = ...

class PolicyApprovalStatusEnum:
    class PolicyApprovalStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DISAPPROVED: int = ...
        APPROVED_LIMITED: int = ...
        APPROVED: int = ...
        AREA_OF_INTEREST_ONLY: int = ...

class PolicyFindingErrorEnum:
    class PolicyFindingError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        POLICY_FINDING: int = ...
        POLICY_TOPIC_NOT_FOUND: int = ...

class PolicyReviewStatusEnum:
    class PolicyReviewStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        REVIEW_IN_PROGRESS: int = ...
        REVIEWED: int = ...
        UNDER_APPEAL: int = ...
        ELIGIBLE_MAY_SERVE: int = ...

class PolicyTopicEntryTypeEnum:
    class PolicyTopicEntryType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PROHIBITED: int = ...
        LIMITED: int = ...
        FULLY_LIMITED: int = ...
        DESCRIPTIVE: int = ...
        BROADENING: int = ...
        AREA_OF_INTEREST_ONLY: int = ...

class PolicyTopicEvidenceDestinationMismatchUrlTypeEnum:
    class PolicyTopicEvidenceDestinationMismatchUrlType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DISPLAY_URL: int = ...
        FINAL_URL: int = ...
        FINAL_MOBILE_URL: int = ...
        TRACKING_URL: int = ...
        MOBILE_TRACKING_URL: int = ...

class PolicyTopicEvidenceDestinationNotWorkingDeviceEnum:
    class PolicyTopicEvidenceDestinationNotWorkingDevice(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DESKTOP: int = ...
        ANDROID: int = ...
        IOS: int = ...

class PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum:
    class PolicyTopicEvidenceDestinationNotWorkingDnsErrorType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        HOSTNAME_NOT_FOUND: int = ...
        GOOGLE_CRAWLER_DNS_ISSUE: int = ...

class PolicyValidationParameterErrorEnum:
    class PolicyValidationParameterError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        UNSUPPORTED_AD_TYPE_FOR_IGNORABLE_POLICY_TOPICS: int = ...
        UNSUPPORTED_AD_TYPE_FOR_EXEMPT_POLICY_VIOLATION_KEYS: int = ...
        CANNOT_SET_BOTH_IGNORABLE_POLICY_TOPICS_AND_EXEMPT_POLICY_VIOLATION_KEYS: int = ...

class PolicyViolationErrorEnum:
    class PolicyViolationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        POLICY_ERROR: int = ...

class PositiveGeoTargetTypeEnum:
    class PositiveGeoTargetType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PRESENCE_OR_INTEREST: int = ...
        SEARCH_INTEREST: int = ...
        PRESENCE: int = ...

class PreferredContentTypeEnum:
    class PreferredContentType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        YOUTUBE_TOP_CONTENT: int = ...

class PriceExtensionPriceQualifierEnum:
    class PriceExtensionPriceQualifier(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FROM: int = ...
        UP_TO: int = ...
        AVERAGE: int = ...

class PriceExtensionPriceUnitEnum:
    class PriceExtensionPriceUnit(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PER_HOUR: int = ...
        PER_DAY: int = ...
        PER_WEEK: int = ...
        PER_MONTH: int = ...
        PER_YEAR: int = ...
        PER_NIGHT: int = ...

class PriceExtensionTypeEnum:
    class PriceExtensionType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BRANDS: int = ...
        EVENTS: int = ...
        LOCATIONS: int = ...
        NEIGHBORHOODS: int = ...
        PRODUCT_CATEGORIES: int = ...
        PRODUCT_TIERS: int = ...
        SERVICES: int = ...
        SERVICE_CATEGORIES: int = ...
        SERVICE_TIERS: int = ...

class PricePlaceholderFieldEnum:
    class PricePlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        TYPE: int = ...
        PRICE_QUALIFIER: int = ...
        TRACKING_TEMPLATE: int = ...
        LANGUAGE: int = ...
        FINAL_URL_SUFFIX: int = ...
        ITEM_1_HEADER: int = ...
        ITEM_1_DESCRIPTION: int = ...
        ITEM_1_PRICE: int = ...
        ITEM_1_UNIT: int = ...
        ITEM_1_FINAL_URLS: int = ...
        ITEM_1_FINAL_MOBILE_URLS: int = ...
        ITEM_2_HEADER: int = ...
        ITEM_2_DESCRIPTION: int = ...
        ITEM_2_PRICE: int = ...
        ITEM_2_UNIT: int = ...
        ITEM_2_FINAL_URLS: int = ...
        ITEM_2_FINAL_MOBILE_URLS: int = ...
        ITEM_3_HEADER: int = ...
        ITEM_3_DESCRIPTION: int = ...
        ITEM_3_PRICE: int = ...
        ITEM_3_UNIT: int = ...
        ITEM_3_FINAL_URLS: int = ...
        ITEM_3_FINAL_MOBILE_URLS: int = ...
        ITEM_4_HEADER: int = ...
        ITEM_4_DESCRIPTION: int = ...
        ITEM_4_PRICE: int = ...
        ITEM_4_UNIT: int = ...
        ITEM_4_FINAL_URLS: int = ...
        ITEM_4_FINAL_MOBILE_URLS: int = ...
        ITEM_5_HEADER: int = ...
        ITEM_5_DESCRIPTION: int = ...
        ITEM_5_PRICE: int = ...
        ITEM_5_UNIT: int = ...
        ITEM_5_FINAL_URLS: int = ...
        ITEM_5_FINAL_MOBILE_URLS: int = ...
        ITEM_6_HEADER: int = ...
        ITEM_6_DESCRIPTION: int = ...
        ITEM_6_PRICE: int = ...
        ITEM_6_UNIT: int = ...
        ITEM_6_FINAL_URLS: int = ...
        ITEM_6_FINAL_MOBILE_URLS: int = ...
        ITEM_7_HEADER: int = ...
        ITEM_7_DESCRIPTION: int = ...
        ITEM_7_PRICE: int = ...
        ITEM_7_UNIT: int = ...
        ITEM_7_FINAL_URLS: int = ...
        ITEM_7_FINAL_MOBILE_URLS: int = ...
        ITEM_8_HEADER: int = ...
        ITEM_8_DESCRIPTION: int = ...
        ITEM_8_PRICE: int = ...
        ITEM_8_UNIT: int = ...
        ITEM_8_FINAL_URLS: int = ...
        ITEM_8_FINAL_MOBILE_URLS: int = ...

class ProductBiddingCategoryLevelEnum:
    class ProductBiddingCategoryLevel(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LEVEL1: int = ...
        LEVEL2: int = ...
        LEVEL3: int = ...
        LEVEL4: int = ...
        LEVEL5: int = ...

class ProductBiddingCategoryStatusEnum:
    class ProductBiddingCategoryStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ACTIVE: int = ...
        OBSOLETE: int = ...

class ProductChannelEnum:
    class ProductChannel(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ONLINE: int = ...
        LOCAL: int = ...

class ProductChannelExclusivityEnum:
    class ProductChannelExclusivity(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SINGLE_CHANNEL: int = ...
        MULTI_CHANNEL: int = ...

class ProductConditionEnum:
    class ProductCondition(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NEW: int = ...
        REFURBISHED: int = ...
        USED: int = ...

class ProductCustomAttributeIndexEnum:
    class ProductCustomAttributeIndex(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INDEX0: int = ...
        INDEX1: int = ...
        INDEX2: int = ...
        INDEX3: int = ...
        INDEX4: int = ...

class ProductTypeLevelEnum:
    class ProductTypeLevel(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LEVEL1: int = ...
        LEVEL2: int = ...
        LEVEL3: int = ...
        LEVEL4: int = ...
        LEVEL5: int = ...

class PromotionExtensionDiscountModifierEnum:
    class PromotionExtensionDiscountModifier(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        UP_TO: int = ...

class PromotionExtensionOccasionEnum:
    class PromotionExtensionOccasion(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NEW_YEARS: int = ...
        CHINESE_NEW_YEAR: int = ...
        VALENTINES_DAY: int = ...
        EASTER: int = ...
        MOTHERS_DAY: int = ...
        FATHERS_DAY: int = ...
        LABOR_DAY: int = ...
        BACK_TO_SCHOOL: int = ...
        HALLOWEEN: int = ...
        BLACK_FRIDAY: int = ...
        CYBER_MONDAY: int = ...
        CHRISTMAS: int = ...
        BOXING_DAY: int = ...
        INDEPENDENCE_DAY: int = ...
        NATIONAL_DAY: int = ...
        END_OF_SEASON: int = ...
        WINTER_SALE: int = ...
        SUMMER_SALE: int = ...
        FALL_SALE: int = ...
        SPRING_SALE: int = ...
        RAMADAN: int = ...
        EID_AL_FITR: int = ...
        EID_AL_ADHA: int = ...
        SINGLES_DAY: int = ...
        WOMENS_DAY: int = ...
        HOLI: int = ...
        PARENTS_DAY: int = ...
        ST_NICHOLAS_DAY: int = ...
        CARNIVAL: int = ...
        EPIPHANY: int = ...
        ROSH_HASHANAH: int = ...
        PASSOVER: int = ...
        HANUKKAH: int = ...
        DIWALI: int = ...
        NAVRATRI: int = ...
        SONGKRAN: int = ...
        YEAR_END_GIFT: int = ...

class PromotionPlaceholderFieldEnum:
    class PromotionPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PROMOTION_TARGET: int = ...
        DISCOUNT_MODIFIER: int = ...
        PERCENT_OFF: int = ...
        MONEY_AMOUNT_OFF: int = ...
        PROMOTION_CODE: int = ...
        ORDERS_OVER_AMOUNT: int = ...
        PROMOTION_START: int = ...
        PROMOTION_END: int = ...
        OCCASION: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        LANGUAGE: int = ...
        FINAL_URL_SUFFIX: int = ...

class ProximityRadiusUnitsEnum:
    class ProximityRadiusUnits(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MILES: int = ...
        KILOMETERS: int = ...

class QualityScoreBucketEnum:
    class QualityScoreBucket(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BELOW_AVERAGE: int = ...
        AVERAGE: int = ...
        ABOVE_AVERAGE: int = ...

class QueryErrorEnum:
    class QueryError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        QUERY_ERROR: int = ...
        BAD_ENUM_CONSTANT: int = ...
        BAD_ESCAPE_SEQUENCE: int = ...
        BAD_FIELD_NAME: int = ...
        BAD_LIMIT_VALUE: int = ...
        BAD_NUMBER: int = ...
        BAD_OPERATOR: int = ...
        BAD_PARAMETER_NAME: int = ...
        BAD_PARAMETER_VALUE: int = ...
        BAD_RESOURCE_TYPE_IN_FROM_CLAUSE: int = ...
        BAD_SYMBOL: int = ...
        BAD_VALUE: int = ...
        DATE_RANGE_TOO_WIDE: int = ...
        DATE_RANGE_TOO_NARROW: int = ...
        EXPECTED_AND: int = ...
        EXPECTED_BY: int = ...
        EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE: int = ...
        EXPECTED_FILTERS_ON_DATE_RANGE: int = ...
        EXPECTED_FROM: int = ...
        EXPECTED_LIST: int = ...
        EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE: int = ...
        EXPECTED_SELECT: int = ...
        EXPECTED_SINGLE_VALUE: int = ...
        EXPECTED_VALUE_WITH_BETWEEN_OPERATOR: int = ...
        INVALID_DATE_FORMAT: int = ...
        INVALID_STRING_VALUE: int = ...
        INVALID_VALUE_WITH_BETWEEN_OPERATOR: int = ...
        INVALID_VALUE_WITH_DURING_OPERATOR: int = ...
        INVALID_VALUE_WITH_LIKE_OPERATOR: int = ...
        OPERATOR_FIELD_MISMATCH: int = ...
        PROHIBITED_EMPTY_LIST_IN_CONDITION: int = ...
        PROHIBITED_ENUM_CONSTANT: int = ...
        PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE: int = ...
        PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE: int = ...
        PROHIBITED_FIELD_IN_SELECT_CLAUSE: int = ...
        PROHIBITED_FIELD_IN_WHERE_CLAUSE: int = ...
        PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE: int = ...
        PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE: int = ...
        PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE: int = ...
        PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE: int = ...
        PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE: int = ...
        PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE: int = ...
        LIMIT_VALUE_TOO_LOW: int = ...
        PROHIBITED_NEWLINE_IN_STRING: int = ...
        PROHIBITED_VALUE_COMBINATION_IN_LIST: int = ...
        PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR: int = ...
        STRING_NOT_TERMINATED: int = ...
        TOO_MANY_SEGMENTS: int = ...
        UNEXPECTED_END_OF_QUERY: int = ...
        UNEXPECTED_FROM_CLAUSE: int = ...
        UNRECOGNIZED_FIELD: int = ...
        UNEXPECTED_INPUT: int = ...
        REQUESTED_METRICS_FOR_MANAGER: int = ...

class QuotaErrorEnum:
    class QuotaError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        RESOURCE_EXHAUSTED: int = ...
        ACCESS_PROHIBITED: int = ...
        RESOURCE_TEMPORARILY_EXHAUSTED: int = ...

class RangeErrorEnum:
    class RangeError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        TOO_LOW: int = ...
        TOO_HIGH: int = ...

class ReachPlanAdLengthEnum:
    class ReachPlanAdLength(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SIX_SECONDS: int = ...
        FIFTEEN_OR_TWENTY_SECONDS: int = ...
        TWENTY_SECONDS_OR_MORE: int = ...

class ReachPlanAgeRangeEnum:
    class ReachPlanAgeRange(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AGE_RANGE_18_24: int = ...
        AGE_RANGE_18_34: int = ...
        AGE_RANGE_18_44: int = ...
        AGE_RANGE_18_49: int = ...
        AGE_RANGE_18_54: int = ...
        AGE_RANGE_18_64: int = ...
        AGE_RANGE_18_65_UP: int = ...
        AGE_RANGE_21_34: int = ...
        AGE_RANGE_25_34: int = ...
        AGE_RANGE_25_44: int = ...
        AGE_RANGE_25_49: int = ...
        AGE_RANGE_25_54: int = ...
        AGE_RANGE_25_64: int = ...
        AGE_RANGE_25_65_UP: int = ...
        AGE_RANGE_35_44: int = ...
        AGE_RANGE_35_49: int = ...
        AGE_RANGE_35_54: int = ...
        AGE_RANGE_35_64: int = ...
        AGE_RANGE_35_65_UP: int = ...
        AGE_RANGE_45_54: int = ...
        AGE_RANGE_45_64: int = ...
        AGE_RANGE_45_65_UP: int = ...
        AGE_RANGE_50_65_UP: int = ...
        AGE_RANGE_55_64: int = ...
        AGE_RANGE_55_65_UP: int = ...
        AGE_RANGE_65_UP: int = ...

class ReachPlanErrorEnum:
    class ReachPlanError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...

class ReachPlanNetworkEnum:
    class ReachPlanNetwork(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        YOUTUBE: int = ...
        GOOGLE_VIDEO_PARTNERS: int = ...
        YOUTUBE_AND_GOOGLE_VIDEO_PARTNERS: int = ...

class RealEstatePlaceholderFieldEnum:
    class RealEstatePlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LISTING_ID: int = ...
        LISTING_NAME: int = ...
        CITY_NAME: int = ...
        DESCRIPTION: int = ...
        ADDRESS: int = ...
        PRICE: int = ...
        FORMATTED_PRICE: int = ...
        IMAGE_URL: int = ...
        PROPERTY_TYPE: int = ...
        LISTING_TYPE: int = ...
        CONTEXTUAL_KEYWORDS: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        ANDROID_APP_LINK: int = ...
        SIMILAR_LISTING_IDS: int = ...
        IOS_APP_LINK: int = ...
        IOS_APP_STORE_ID: int = ...

class RecommendationErrorEnum:
    class RecommendationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BUDGET_AMOUNT_TOO_SMALL: int = ...
        BUDGET_AMOUNT_TOO_LARGE: int = ...
        INVALID_BUDGET_AMOUNT: int = ...
        POLICY_ERROR: int = ...
        INVALID_BID_AMOUNT: int = ...
        ADGROUP_KEYWORD_LIMIT: int = ...
        RECOMMENDATION_ALREADY_APPLIED: int = ...
        RECOMMENDATION_INVALIDATED: int = ...
        TOO_MANY_OPERATIONS: int = ...
        NO_OPERATIONS: int = ...
        DIFFERENT_TYPES_NOT_SUPPORTED: int = ...
        DUPLICATE_RESOURCE_NAME: int = ...
        RECOMMENDATION_ALREADY_DISMISSED: int = ...
        INVALID_APPLY_REQUEST: int = ...

class RecommendationTypeEnum:
    class RecommendationType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CAMPAIGN_BUDGET: int = ...
        KEYWORD: int = ...
        TEXT_AD: int = ...
        TARGET_CPA_OPT_IN: int = ...
        MAXIMIZE_CONVERSIONS_OPT_IN: int = ...
        ENHANCED_CPC_OPT_IN: int = ...
        SEARCH_PARTNERS_OPT_IN: int = ...
        MAXIMIZE_CLICKS_OPT_IN: int = ...
        OPTIMIZE_AD_ROTATION: int = ...
        CALLOUT_EXTENSION: int = ...
        SITELINK_EXTENSION: int = ...
        CALL_EXTENSION: int = ...
        KEYWORD_MATCH_TYPE: int = ...
        MOVE_UNUSED_BUDGET: int = ...

class RegionCodeErrorEnum:
    class RegionCodeError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_REGION_CODE: int = ...

class RequestErrorEnum:
    class RequestError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        RESOURCE_NAME_MISSING: int = ...
        RESOURCE_NAME_MALFORMED: int = ...
        BAD_RESOURCE_ID: int = ...
        INVALID_CUSTOMER_ID: int = ...
        OPERATION_REQUIRED: int = ...
        RESOURCE_NOT_FOUND: int = ...
        INVALID_PAGE_TOKEN: int = ...
        EXPIRED_PAGE_TOKEN: int = ...
        INVALID_PAGE_SIZE: int = ...
        REQUIRED_FIELD_MISSING: int = ...
        IMMUTABLE_FIELD: int = ...
        TOO_MANY_MUTATE_OPERATIONS: int = ...
        CANNOT_BE_EXECUTED_BY_MANAGER_ACCOUNT: int = ...
        CANNOT_MODIFY_FOREIGN_FIELD: int = ...
        INVALID_ENUM_VALUE: int = ...
        DEVELOPER_TOKEN_PARAMETER_MISSING: int = ...
        LOGIN_CUSTOMER_ID_PARAMETER_MISSING: int = ...
        VALIDATE_ONLY_REQUEST_HAS_PAGE_TOKEN: int = ...
        CANNOT_RETURN_SUMMARY_ROW_FOR_REQUEST_WITHOUT_METRICS: int = ...
        CANNOT_RETURN_SUMMARY_ROW_FOR_VALIDATE_ONLY_REQUESTS: int = ...
        INCONSISTENT_RETURN_SUMMARY_ROW_VALUE: int = ...
        TOTAL_RESULTS_COUNT_NOT_ORIGINALLY_REQUESTED: int = ...

class ResourceAccessDeniedErrorEnum:
    class ResourceAccessDeniedError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        WRITE_ACCESS_DENIED: int = ...

class ResourceCountLimitExceededErrorEnum:
    class ResourceCountLimitExceededError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ACCOUNT_LIMIT: int = ...
        CAMPAIGN_LIMIT: int = ...
        ADGROUP_LIMIT: int = ...
        AD_GROUP_AD_LIMIT: int = ...
        AD_GROUP_CRITERION_LIMIT: int = ...
        SHARED_SET_LIMIT: int = ...
        MATCHING_FUNCTION_LIMIT: int = ...
        RESPONSE_ROW_LIMIT_EXCEEDED: int = ...
        RESOURCE_LIMIT: int = ...

class SearchEngineResultsPageTypeEnum:
    class SearchEngineResultsPageType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ADS_ONLY: int = ...
        ORGANIC_ONLY: int = ...
        ADS_AND_ORGANIC: int = ...

class SearchTermMatchTypeEnum:
    class SearchTermMatchType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        BROAD: int = ...
        EXACT: int = ...
        PHRASE: int = ...
        NEAR_EXACT: int = ...
        NEAR_PHRASE: int = ...

class SearchTermTargetingStatusEnum:
    class SearchTermTargetingStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ADDED: int = ...
        EXCLUDED: int = ...
        ADDED_EXCLUDED: int = ...
        NONE: int = ...

class ServedAssetFieldTypeEnum:
    class ServedAssetFieldType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        HEADLINE_1: int = ...
        HEADLINE_2: int = ...
        HEADLINE_3: int = ...
        DESCRIPTION_1: int = ...
        DESCRIPTION_2: int = ...

class SettingErrorEnum:
    class SettingError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SETTING_TYPE_IS_NOT_AVAILABLE: int = ...
        SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN: int = ...
        TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP: int = ...
        TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL: int = ...
        TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP: int = ...
        DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT: int = ...
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME: int = ...
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME: int = ...
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE: int = ...
        TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN: int = ...

class SharedCriterionErrorEnum:
    class SharedCriterionError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CRITERION_TYPE_NOT_ALLOWED_FOR_SHARED_SET_TYPE: int = ...

class SharedSetErrorEnum:
    class SharedSetError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE: int = ...
        DUPLICATE_NAME: int = ...
        SHARED_SET_REMOVED: int = ...
        SHARED_SET_IN_USE: int = ...

class SharedSetStatusEnum:
    class SharedSetStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        REMOVED: int = ...

class SharedSetTypeEnum:
    class SharedSetType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NEGATIVE_KEYWORDS: int = ...
        NEGATIVE_PLACEMENTS: int = ...

class SimulationModificationMethodEnum:
    class SimulationModificationMethod(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        UNIFORM: int = ...
        DEFAULT: int = ...

class SimulationTypeEnum:
    class SimulationType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CPC_BID: int = ...
        CPV_BID: int = ...
        TARGET_CPA: int = ...
        BID_MODIFIER: int = ...

class SitelinkPlaceholderFieldEnum:
    class SitelinkPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        TEXT: int = ...
        LINE_1: int = ...
        LINE_2: int = ...
        FINAL_URLS: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        FINAL_URL_SUFFIX: int = ...

class SizeLimitErrorEnum:
    class SizeLimitError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        REQUEST_SIZE_LIMIT_EXCEEDED: int = ...
        RESPONSE_SIZE_LIMIT_EXCEEDED: int = ...

class SlotEnum:
    class Slot(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SEARCH_SIDE: int = ...
        SEARCH_TOP: int = ...
        SEARCH_OTHER: int = ...
        CONTENT: int = ...
        SEARCH_PARTNER_TOP: int = ...
        SEARCH_PARTNER_OTHER: int = ...
        MIXED: int = ...

class SpendingLimitTypeEnum:
    class SpendingLimitType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INFINITE: int = ...

class StringFormatErrorEnum:
    class StringFormatError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ILLEGAL_CHARS: int = ...
        INVALID_FORMAT: int = ...

class StringLengthErrorEnum:
    class StringLengthError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EMPTY: int = ...
        TOO_SHORT: int = ...
        TOO_LONG: int = ...

class StructuredSnippetPlaceholderFieldEnum:
    class StructuredSnippetPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        HEADER: int = ...
        SNIPPETS: int = ...

class SummaryRowSettingEnum:
    class SummaryRowSetting(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NO_SUMMARY_ROW: int = ...
        SUMMARY_ROW_WITH_RESULTS: int = ...
        SUMMARY_ROW_ONLY: int = ...

class SystemManagedResourceSourceEnum:
    class SystemManagedResourceSource(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AD_VARIATIONS: int = ...

class TargetCpaOptInRecommendationGoalEnum:
    class TargetCpaOptInRecommendationGoal(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        SAME_COST: int = ...
        SAME_CONVERSIONS: int = ...
        SAME_CPA: int = ...
        CLOSEST_CPA: int = ...

class TargetImpressionShareLocationEnum:
    class TargetImpressionShareLocation(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ANYWHERE_ON_PAGE: int = ...
        TOP_OF_PAGE: int = ...
        ABSOLUTE_TOP_OF_PAGE: int = ...

class TargetRestrictionOperation:
    class Operator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ADD: int = ...
        REMOVE: int = ...

class TargetingDimensionEnum:
    class TargetingDimension(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        KEYWORD: int = ...
        AUDIENCE: int = ...
        TOPIC: int = ...
        GENDER: int = ...
        AGE_RANGE: int = ...
        PLACEMENT: int = ...
        PARENTAL_STATUS: int = ...
        INCOME_RANGE: int = ...

class TimeTypeEnum:
    class TimeType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        NOW: int = ...
        FOREVER: int = ...

class TimeZoneErrorEnum:
    class TimeZoneError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_TIME_ZONE: int = ...

class TrackingCodePageFormatEnum:
    class TrackingCodePageFormat(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        HTML: int = ...
        AMP: int = ...

class TrackingCodeTypeEnum:
    class TrackingCodeType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        WEBPAGE: int = ...
        WEBPAGE_ONCLICK: int = ...
        CLICK_TO_CALL: int = ...
        WEBSITE_CALL: int = ...

class TravelPlaceholderFieldEnum:
    class TravelPlaceholderField(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        DESTINATION_ID: int = ...
        ORIGIN_ID: int = ...
        TITLE: int = ...
        DESTINATION_NAME: int = ...
        ORIGIN_NAME: int = ...
        PRICE: int = ...
        FORMATTED_PRICE: int = ...
        SALE_PRICE: int = ...
        FORMATTED_SALE_PRICE: int = ...
        IMAGE_URL: int = ...
        CATEGORY: int = ...
        CONTEXTUAL_KEYWORDS: int = ...
        DESTINATION_ADDRESS: int = ...
        FINAL_URL: int = ...
        FINAL_MOBILE_URLS: int = ...
        TRACKING_URL: int = ...
        ANDROID_APP_LINK: int = ...
        SIMILAR_DESTINATION_IDS: int = ...
        IOS_APP_LINK: int = ...
        IOS_APP_STORE_ID: int = ...

class UrlFieldErrorEnum:
    class UrlFieldError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        INVALID_TRACKING_URL_TEMPLATE: int = ...
        INVALID_TAG_IN_TRACKING_URL_TEMPLATE: int = ...
        MISSING_TRACKING_URL_TEMPLATE_TAG: int = ...
        MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE: int = ...
        INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE: int = ...
        MALFORMED_TRACKING_URL_TEMPLATE: int = ...
        MISSING_HOST_IN_TRACKING_URL_TEMPLATE: int = ...
        INVALID_TLD_IN_TRACKING_URL_TEMPLATE: int = ...
        REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG: int = ...
        INVALID_FINAL_URL: int = ...
        INVALID_TAG_IN_FINAL_URL: int = ...
        REDUNDANT_NESTED_FINAL_URL_TAG: int = ...
        MISSING_PROTOCOL_IN_FINAL_URL: int = ...
        INVALID_PROTOCOL_IN_FINAL_URL: int = ...
        MALFORMED_FINAL_URL: int = ...
        MISSING_HOST_IN_FINAL_URL: int = ...
        INVALID_TLD_IN_FINAL_URL: int = ...
        INVALID_FINAL_MOBILE_URL: int = ...
        INVALID_TAG_IN_FINAL_MOBILE_URL: int = ...
        REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG: int = ...
        MISSING_PROTOCOL_IN_FINAL_MOBILE_URL: int = ...
        INVALID_PROTOCOL_IN_FINAL_MOBILE_URL: int = ...
        MALFORMED_FINAL_MOBILE_URL: int = ...
        MISSING_HOST_IN_FINAL_MOBILE_URL: int = ...
        INVALID_TLD_IN_FINAL_MOBILE_URL: int = ...
        INVALID_FINAL_APP_URL: int = ...
        INVALID_TAG_IN_FINAL_APP_URL: int = ...
        REDUNDANT_NESTED_FINAL_APP_URL_TAG: int = ...
        MULTIPLE_APP_URLS_FOR_OSTYPE: int = ...
        INVALID_OSTYPE: int = ...
        INVALID_PROTOCOL_FOR_APP_URL: int = ...
        INVALID_PACKAGE_ID_FOR_APP_URL: int = ...
        URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT: int = ...
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY: int = ...
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE: int = ...
        INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE: int = ...
        REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG: int = ...
        MISSING_PROTOCOL: int = ...
        INVALID_PROTOCOL: int = ...
        INVALID_URL: int = ...
        DESTINATION_URL_DEPRECATED: int = ...
        INVALID_TAG_IN_URL: int = ...
        MISSING_URL_TAG: int = ...
        DUPLICATE_URL_ID: int = ...
        INVALID_URL_ID: int = ...
        FINAL_URL_SUFFIX_MALFORMED: int = ...
        INVALID_TAG_IN_FINAL_URL_SUFFIX: int = ...
        INVALID_TOP_LEVEL_DOMAIN: int = ...
        MALFORMED_TOP_LEVEL_DOMAIN: int = ...
        MALFORMED_URL: int = ...
        MISSING_HOST: int = ...
        NULL_CUSTOM_PARAMETER_VALUE: int = ...

class UserInterestTaxonomyTypeEnum:
    class UserInterestTaxonomyType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AFFINITY: int = ...
        IN_MARKET: int = ...
        MOBILE_APP_INSTALL_USER: int = ...
        VERTICAL_GEO: int = ...
        NEW_SMART_PHONE_USER: int = ...

class UserListAccessStatusEnum:
    class UserListAccessStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ENABLED: int = ...
        DISABLED: int = ...

class UserListClosingReasonEnum:
    class UserListClosingReason(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        UNUSED: int = ...

class UserListCombinedRuleOperatorEnum:
    class UserListCombinedRuleOperator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AND: int = ...
        AND_NOT: int = ...

class UserListCrmDataSourceTypeEnum:
    class UserListCrmDataSourceType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        FIRST_PARTY: int = ...
        THIRD_PARTY_CREDIT_BUREAU: int = ...
        THIRD_PARTY_VOTER_FILE: int = ...

class UserListDateRuleItemOperatorEnum:
    class UserListDateRuleItemOperator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EQUALS: int = ...
        NOT_EQUALS: int = ...
        BEFORE: int = ...
        AFTER: int = ...

class UserListErrorEnum:
    class UserListError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED: int = ...
        CONCRETE_TYPE_REQUIRED: int = ...
        CONVERSION_TYPE_ID_REQUIRED: int = ...
        DUPLICATE_CONVERSION_TYPES: int = ...
        INVALID_CONVERSION_TYPE: int = ...
        INVALID_DESCRIPTION: int = ...
        INVALID_NAME: int = ...
        INVALID_TYPE: int = ...
        CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND: int = ...
        INVALID_USER_LIST_LOGICAL_RULE_OPERAND: int = ...
        NAME_ALREADY_USED: int = ...
        NEW_CONVERSION_TYPE_NAME_REQUIRED: int = ...
        CONVERSION_TYPE_NAME_ALREADY_USED: int = ...
        OWNERSHIP_REQUIRED_FOR_SET: int = ...
        USER_LIST_MUTATE_NOT_SUPPORTED: int = ...
        INVALID_RULE: int = ...
        INVALID_DATE_RANGE: int = ...
        CAN_NOT_MUTATE_SENSITIVE_USERLIST: int = ...
        MAX_NUM_RULEBASED_USERLISTS: int = ...
        CANNOT_MODIFY_BILLABLE_RECORD_COUNT: int = ...
        APP_ID_NOT_SET: int = ...
        USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST: int = ...
        ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA: int = ...
        RULE_TYPE_IS_NOT_SUPPORTED: int = ...
        CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND: int = ...
        CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS: int = ...

class UserListLogicalRuleOperatorEnum:
    class UserListLogicalRuleOperator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        ALL: int = ...
        ANY: int = ...
        NONE: int = ...

class UserListMembershipStatusEnum:
    class UserListMembershipStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        OPEN: int = ...
        CLOSED: int = ...

class UserListNumberRuleItemOperatorEnum:
    class UserListNumberRuleItemOperator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        GREATER_THAN: int = ...
        GREATER_THAN_OR_EQUAL: int = ...
        EQUALS: int = ...
        NOT_EQUALS: int = ...
        LESS_THAN: int = ...
        LESS_THAN_OR_EQUAL: int = ...

class UserListPrepopulationStatusEnum:
    class UserListPrepopulationStatus(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        REQUESTED: int = ...
        FINISHED: int = ...
        FAILED: int = ...

class UserListRuleTypeEnum:
    class UserListRuleType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        AND_OF_ORS: int = ...
        OR_OF_ANDS: int = ...

class UserListSizeRangeEnum:
    class UserListSizeRange(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        LESS_THAN_FIVE_HUNDRED: int = ...
        LESS_THAN_ONE_THOUSAND: int = ...
        ONE_THOUSAND_TO_TEN_THOUSAND: int = ...
        TEN_THOUSAND_TO_FIFTY_THOUSAND: int = ...
        FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND: int = ...
        ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND: int = ...
        THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND: int = ...
        FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION: int = ...
        ONE_MILLION_TO_TWO_MILLION: int = ...
        TWO_MILLION_TO_THREE_MILLION: int = ...
        THREE_MILLION_TO_FIVE_MILLION: int = ...
        FIVE_MILLION_TO_TEN_MILLION: int = ...
        TEN_MILLION_TO_TWENTY_MILLION: int = ...
        TWENTY_MILLION_TO_THIRTY_MILLION: int = ...
        THIRTY_MILLION_TO_FIFTY_MILLION: int = ...
        OVER_FIFTY_MILLION: int = ...

class UserListStringRuleItemOperatorEnum:
    class UserListStringRuleItemOperator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        CONTAINS: int = ...
        EQUALS: int = ...
        STARTS_WITH: int = ...
        ENDS_WITH: int = ...
        NOT_EQUALS: int = ...
        NOT_CONTAINS: int = ...
        NOT_STARTS_WITH: int = ...
        NOT_ENDS_WITH: int = ...

class UserListTypeEnum:
    class UserListType(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        REMARKETING: int = ...
        LOGICAL: int = ...
        EXTERNAL_REMARKETING: int = ...
        RULE_BASED: int = ...
        SIMILAR: int = ...
        CRM_BASED: int = ...

class VanityPharmaDisplayUrlModeEnum:
    class VanityPharmaDisplayUrlMode(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        MANUFACTURER_WEBSITE_URL: int = ...
        WEBSITE_DESCRIPTION: int = ...

class VanityPharmaTextEnum:
    class VanityPharmaText(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        PRESCRIPTION_TREATMENT_WEBSITE_EN: int = ...
        PRESCRIPTION_TREATMENT_WEBSITE_ES: int = ...
        PRESCRIPTION_DEVICE_WEBSITE_EN: int = ...
        PRESCRIPTION_DEVICE_WEBSITE_ES: int = ...
        MEDICAL_DEVICE_WEBSITE_EN: int = ...
        MEDICAL_DEVICE_WEBSITE_ES: int = ...
        PREVENTATIVE_TREATMENT_WEBSITE_EN: int = ...
        PREVENTATIVE_TREATMENT_WEBSITE_ES: int = ...
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN: int = ...
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES: int = ...
        PRESCRIPTION_VACCINE_WEBSITE_EN: int = ...
        PRESCRIPTION_VACCINE_WEBSITE_ES: int = ...

class WebpageConditionOperandEnum:
    class WebpageConditionOperand(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        URL: int = ...
        CATEGORY: int = ...
        PAGE_TITLE: int = ...
        PAGE_CONTENT: int = ...
        CUSTOM_LABEL: int = ...

class WebpageConditionOperatorEnum:
    class WebpageConditionOperator(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        EQUALS: int = ...
        CONTAINS: int = ...

class YoutubeVideoRegistrationErrorEnum:
    class YoutubeVideoRegistrationError(enum.IntEnum):
        UNSPECIFIED: int = ...
        UNKNOWN: int = ...
        VIDEO_NOT_FOUND: int = ...
        VIDEO_NOT_ACCESSIBLE: int = ...
        VIDEO_NOT_ELIGIBLE: int = ...
